pub struct Extension;Trait Implementations
Sourceimpl CastReduce for Extension
impl CastReduce for Extension
Sourceimpl CompareKernel for Extension
impl CompareKernel for Extension
fn compare( lhs: ArrayView<'_, Extension>, rhs: &ArrayRef, operator: CompareOperator, _ctx: &mut ExecutionCtx, ) -> Result<Option<ArrayRef>, VortexError>
Sourceimpl FilterReduce for Extension
impl FilterReduce for Extension
Sourceimpl MaskReduce for Extension
impl MaskReduce for Extension
Sourceimpl OperationsVTable<Extension> for Extension
impl OperationsVTable<Extension> for Extension
Sourceimpl SliceReduce for Extension
impl SliceReduce for Extension
Sourceimpl TakeExecute for Extension
impl TakeExecute for Extension
Sourceimpl VTable for Extension
impl VTable for Extension
type ArrayData = ExtensionData
type OperationsVTable = Extension
type ValidityVTable = ValidityVTableFromChild
Sourcefn nbuffers(_array: ArrayView<'_, Extension>) -> usize
fn nbuffers(_array: ArrayView<'_, Extension>) -> usize
Returns the number of buffers in the array.
Sourcefn buffer(_array: ArrayView<'_, Extension>, idx: usize) -> BufferHandle
fn buffer(_array: ArrayView<'_, Extension>, idx: usize) -> BufferHandle
Returns the buffer at the given index. Read more
Sourcefn buffer_name(_array: ArrayView<'_, Extension>, _idx: usize) -> Option<String>
fn buffer_name(_array: ArrayView<'_, Extension>, _idx: usize) -> Option<String>
Returns the name of the buffer at the given index, or
None if unnamed.Sourcefn slot_name(_array: ArrayView<'_, Extension>, idx: usize) -> String
fn slot_name(_array: ArrayView<'_, Extension>, idx: usize) -> String
Returns the name of the slot at the given index. Read more
Sourcefn serialize(
_array: ArrayView<'_, Extension>,
_session: &VortexSession,
) -> Result<Option<Vec<u8>>, VortexError>
fn serialize( _array: ArrayView<'_, Extension>, _session: &VortexSession, ) -> Result<Option<Vec<u8>>, VortexError>
Serialize metadata into a byte buffer for IPC or file storage.
Return
None if the array cannot be serialized.Sourcefn validate(
&self,
data: &ExtensionData,
dtype: &DType,
len: usize,
slots: &[Option<ArrayRef>],
) -> Result<(), VortexError>
fn validate( &self, data: &ExtensionData, dtype: &DType, len: usize, slots: &[Option<ArrayRef>], ) -> Result<(), VortexError>
Validates that externally supplied logical metadata matches the array data.
Sourcefn deserialize(
&self,
dtype: &DType,
len: usize,
metadata: &[u8],
_buffers: &[BufferHandle],
children: &dyn ArrayChildren,
_session: &VortexSession,
) -> Result<ArrayParts<Extension>, VortexError>
fn deserialize( &self, dtype: &DType, len: usize, metadata: &[u8], _buffers: &[BufferHandle], children: &dyn ArrayChildren, _session: &VortexSession, ) -> Result<ArrayParts<Extension>, VortexError>
Deserialize an array from serialized components.
Sourcefn execute(
array: Array<Extension>,
_ctx: &mut ExecutionCtx,
) -> Result<ExecutionResult, VortexError>
fn execute( array: Array<Extension>, _ctx: &mut ExecutionCtx, ) -> Result<ExecutionResult, VortexError>
Execute this array by returning an
ExecutionResult. Read moreSourcefn reduce_parent(
array: ArrayView<'_, Extension>,
parent: &ArrayRef,
child_idx: usize,
) -> Result<Option<ArrayRef>, VortexError>
fn reduce_parent( array: ArrayView<'_, Extension>, parent: &ArrayRef, child_idx: usize, ) -> Result<Option<ArrayRef>, VortexError>
Attempt to perform a reduction of the parent of this array.
Sourcefn execute_parent(
array: ArrayView<'_, Extension>,
parent: &ArrayRef,
child_idx: usize,
ctx: &mut ExecutionCtx,
) -> Result<Option<ArrayRef>, VortexError>
fn execute_parent( array: ArrayView<'_, Extension>, parent: &ArrayRef, child_idx: usize, ctx: &mut ExecutionCtx, ) -> Result<Option<ArrayRef>, VortexError>
Attempt to execute the parent of this array.
Sourcefn nchildren(array: ArrayView<'_, Self>) -> usize
fn nchildren(array: ArrayView<'_, Self>) -> usize
Returns the number of children in the array. Read more
Sourcefn child(array: ArrayView<'_, Self>, idx: usize) -> ArrayRef
fn child(array: ArrayView<'_, Self>, idx: usize) -> ArrayRef
Returns the child at the given index. Read more
Sourcefn child_name(array: ArrayView<'_, Self>, idx: usize) -> String
fn child_name(array: ArrayView<'_, Self>, idx: usize) -> String
Returns the name of the child at the given index. Read more
Sourcefn append_to_builder(
array: ArrayView<'_, Self>,
builder: &mut dyn ArrayBuilder,
ctx: &mut ExecutionCtx,
) -> Result<(), VortexError>
fn append_to_builder( array: ArrayView<'_, Self>, builder: &mut dyn ArrayBuilder, ctx: &mut ExecutionCtx, ) -> Result<(), VortexError>
Writes the array into a canonical builder.