Display

Trait Display 

1.36.0 · Source
pub trait Display {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
Format trait for an empty format, {}.

Implementing this trait for a type will automatically implement the ToString trait for the type, allowing the usage of the .to_string() method. Prefer implementing the Display trait for a type, rather than ToString.

Display is similar to Debug, but Display is for user-facing output, and so cannot be derived.

For more information on formatters, see the module-level documentation.

Completeness and parseability

Display for a type might not necessarily be a lossless or complete representation of the type. It may omit internal state, precision, or other information the type does not consider important for user-facing output, as determined by the type. As such, the output of Display might not be possible to parse, and even if it is, the result of parsing might not exactly match the original value.

However, if a type has a lossless Display implementation whose output is meant to be conveniently machine-parseable and not just meant for human consumption, then the type may wish to accept the same format in FromStr, and document that usage. Having both Display and FromStr implementations where the result of Display cannot be parsed with FromStr may surprise users.

Internationalization

Because a type can only have one Display implementation, it is often preferable to only implement Display when there is a single most “obvious” way that values can be formatted as text. This could mean formatting according to the “invariant” culture and “undefined” locale, or it could mean that the type display is designed for a specific culture/locale, such as developer logs.

If not all values have a justifiably canonical textual format or if you want to support alternative formats not covered by the standard set of possible formatting traits, the most flexible approach is display adapters: methods like str::escape_default or Path::display which create a wrapper implementing Display to output the specific display format.

Examples

Implementing Display on a type:

use std::fmt;

struct Point {
    x: i32,
    y: i32,
}

impl fmt::Display for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.x, self.y)
    }
}

let origin = Point { x: 0, y: 0 };

assert_eq!(format!("The origin is: {origin}"), "The origin is: (0, 0)");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Examples
use std::fmt;

struct Position {
    longitude: f32,
    latitude: f32,
}

impl fmt::Display for Position {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.longitude, self.latitude)
    }
}

assert_eq!(
    "(1.987, 2.983)",
    format!("{}", Position { longitude: 1.987, latitude: 2.983, }),
);

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Display for !

Source

impl Display for ALPData

Source

impl Display for ALPRDData

Source

impl Display for Aborted

1.26.0 · Source

impl Display for AccessError

Source

impl Display for AcquireError

1.4.0 · Source

impl Display for AddrParseError

Source

impl Display for AggregateFnOptions<'_>

Source

impl Display for AggregateFnRef

Source

impl Display for Alignment

Source

impl Display for vortex::array::smallvec::alloc::alloc::AllocError

Source

impl Display for allocator_api2::stable::alloc::AllocError

1.0.0 · Source

impl Display for Arguments<'_>

Source

impl Display for Arity

Source

impl Display for ArrayRef

Display the encoding and limited metadata of this array.

Examples

let array = buffer![0_i16, 1, 2, 3, 4].into_array();
assert_eq!(
    format!("{}", array),
    "vortex.primitive(i16, len=5)",
);
Source

impl Display for ArrowError

Source

impl Display for AsciiChar

Source

impl Display for Ast

Print a display representation of this Ast.

This does not preserve any of the original whitespace formatting that may have originally been present in the concrete syntax from which this Ast was generated.

This implementation uses constant stack space and heap space proportional to the size of the Ast.

Source

impl Display for Attribute

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Attributes

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Authority

1.65.0 · Source

impl Display for Backtrace

Source

impl Display for rand::distr::bernoulli::BernoulliError

Source

impl Display for rand::distr::bernoulli::BernoulliError

Source

impl Display for BetweenOptions

Source

impl Display for BigEndian

Source

impl Display for BigInt

Source

impl Display for BigUint

Source

impl Display for BinaryScalar<'_>

Source

impl Display for BitBuffer

Source

impl Display for BitPackedData

Source

impl Display for BoolData

Source

impl Display for BoolScalar<'_>

1.13.0 · Source

impl Display for BorrowError

1.13.0 · Source

impl Display for BorrowMutError

Source

impl Display for BoundedMaxOptions

Source

impl Display for BoundedMinOptions

Source

impl Display for Braced

Source

impl Display for regex_automata::dfa::onepass::BuildError

Source

impl Display for regex_automata::hybrid::error::BuildError

Source

impl Display for regex_automata::meta::error::BuildError

Source

impl Display for regex_automata::nfa::thompson::error::BuildError

Source

impl Display for aho_corasick::util::error::BuildError

Source

impl Display for ByteBoolData

Source

impl Display for ByteStr

Source

impl Display for ByteString

Source

impl Display for CacheError

Source

impl Display for Canceled

Source

impl Display for CaseFoldError

Source

impl Display for CaseWhenOptions

1.34.0 · Source

impl Display for CharTryFromError

Source

impl Display for CheckedCastError

Available on non-SPIR-V only.
Source

impl Display for ChunkedData

Source

impl Display for ChunkedStore

Source

impl Display for CloseError

Source

impl Display for CollectionAllocErr

Source

impl Display for CompareOperator

Source

impl Display for ConstantData

Source

impl Display for ContentSizeError

Source

impl Display for DDSketchError

Source

impl Display for DType

Source

impl Display for DataError

Source

impl Display for DataErrorKind

Source

impl Display for DataIdentifierBorrowed<'_>

Source

impl Display for DataLocale

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for DataType

Source

impl Display for jiff::civil::date::Date

Source

impl Display for DatePart

Source

impl Display for jiff::civil::datetime::DateTime

Converts a DateTime into an ISO 8601 compliant string.

Formatting options supported

  • std::fmt::Formatter::precision can be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.

Example

This shows the default rendering:

use jiff::civil::date;

// No fractional seconds:
let dt = date(2024, 6, 15).at(7, 0, 0, 0);
assert_eq!(format!("{dt}"), "2024-06-15T07:00:00");

// With fractional seconds:
let dt = date(2024, 6, 15).at(7, 0, 0, 123_000_000);
assert_eq!(format!("{dt}"), "2024-06-15T07:00:00.123");

Example: setting the precision

use jiff::civil::date;

let dt = date(2024, 6, 15).at(7, 0, 0, 123_000_000);
assert_eq!(format!("{dt:.6}"), "2024-06-15T07:00:00.123000");
// Precision values greater than 9 are clamped to 9.
assert_eq!(format!("{dt:.300}"), "2024-06-15T07:00:00.123000000");
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(format!("{dt:.0}"), "2024-06-15T07:00:00");
Source

impl Display for DateTimePartsData

Source

impl Display for DateValue

Source

impl Display for DecimalBytePartsData

Source

impl Display for DecimalDType

Source

impl Display for DecimalData

Source

impl Display for DecimalScalar<'_>

Source

impl Display for DecimalType

Source

impl Display for DecimalValue

Source

impl Display for prost::error::DecodeError

Source

impl Display for base64::decode::DecodeError

Source

impl Display for sketches_ddsketch::encoding::DecodeError

Source

impl Display for DecodeSliceError

1.9.0 · Source

impl Display for DecodeUtf16Error

Source

impl Display for DeltaData

Source

impl Display for DeserializeError

Source

impl Display for DictData

1.87.0 · Source

impl Display for std::ffi::os_str::Display<'_>

1.0.0 · Source

impl Display for std::path::Display<'_>

Source

impl Display for DisplayArrayAs<'_>

Source

impl Display for DisplayLayoutTree

Source

impl Display for DisplayTreeExpr<'_>

Source

impl Display for DuplicateHandling

Source

impl Display for Duration

Source

impl Display for DurationError

Source

impl Display for DynamicComparisonExpr

Source

impl Display for Elapsed

Source

impl Display for rand::distr::slice::Empty

Source

impl Display for rand::distr::slice::Empty

Source

impl Display for EmptyArrayData

Source

impl Display for EmptyMetadata

Source

impl Display for vortex::aggregate_fn::EmptyOptions

Source

impl Display for vortex::scalar_fn::EmptyOptions

Source

impl Display for EncodeError

Source

impl Display for EncodeSliceError

Source

impl Display for EnterError

Source

impl Display for ErrString

Source

impl Display for rustix::backend::io::errno::Errno

Source

impl Display for errno::Errno

1.0.0 · Source

impl Display for std::io::error::Error

1.0.0 · Source

impl Display for vortex::array::smallvec::alloc::fmt::Error

Source

impl Display for getrandom::error::Error

Source

impl Display for serde_core::de::value::Error

Source

impl Display for serde_json::error::Error

Source

impl Display for object_store::path::Error

Source

impl Display for object_store::Error

Source

impl Display for tokio::time::error::Error

Source

impl Display for icu_collections::codepointtrie::error::Error

Source

impl Display for walkdir::error::Error

Source

impl Display for http::error::Error

Source

impl Display for jiff::error::Error

Source

impl Display for uuid::error::Error

Source

impl Display for getrandom::error::Error

Source

impl Display for lexical_util::error::Error

Source

impl Display for regex::error::Error

Source

impl Display for regex_syntax::ast::Error

Source

impl Display for regex_syntax::error::Error

Source

impl Display for regex_syntax::hir::Error

Source

impl Display for rand::distr::uniform::Error

Source

impl Display for rand::distr::weighted::Error

Source

impl Display for onpair::config::Error

Source

impl Display for rand::distr::uniform::Error

Source

impl Display for rand::distr::weighted::Error

Source

impl Display for rand_core::error::Error

1.60.0 · Source

impl Display for core::io::error::ErrorKind

Source

impl Display for regex_syntax::ast::ErrorKind

Source

impl Display for regex_syntax::hir::ErrorKind

Source

impl Display for Errors

1.20.0 · Source

impl Display for core::char::EscapeDebug

1.39.0 · Source

impl Display for core::ascii::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeUnicode

Source

impl Display for ExecutionCtx

1.0.0 · Source

impl Display for ExitStatus

Source

impl Display for ExitStatusError

Source

impl Display for Exponents

Source

impl Display for Expression

The default display implementation for expressions uses the ‘SQL’-style format.

Source

impl Display for ExtDTypeRef

Source

impl Display for ExtScalar<'_>

Source

impl Display for ExtendedTable

Source

impl Display for Extensions

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for FSSTData

Source

impl Display for vortex::dtype::Field

Source

impl Display for arrow_schema::field::Field

Source

impl Display for tracing_core::field::Field

Source

impl Display for FieldName

Source

impl Display for FieldNames

Source

impl Display for FieldPath

Source

impl Display for FieldSelection

Source

impl Display for FieldSet

Source

impl Display for Fields

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for FilterData

Source

impl Display for FixedOffset

Source

impl Display for FixedShapeTensorMetadata

Source

impl Display for FixedSizeListData

Source

impl Display for FoRData

Source

impl Display for ForeignScalarFnOptions

Source

impl Display for FormatVersion

1.69.0 · Source

impl Display for FromBytesUntilNulError

1.17.0 · Source

impl Display for FromBytesWithNulError

1.0.0 · Source

impl Display for FromUtf8Error

1.0.0 · Source

impl Display for FromUtf16Error

1.58.0 · Source

impl Display for FromVecWithNulError

1.86.0 · Source

impl Display for vortex::array::smallvec::alloc::slice::GetDisjointMutError

Source

impl Display for slab::GetDisjointMutError

Source

impl Display for GetRange

Source

impl Display for GetTimezoneError

Source

impl Display for Gid

Source

impl Display for GlobError

Source

impl Display for GroupInfoError

Source

impl Display for HeaderName

Source

impl Display for Hir

Print a display representation of this Hir.

The result of this is a valid regular expression pattern string.

This implementation uses constant stack space and heap space proportional to the size of the Hir.

Source

impl Display for Hyphenated

Source

impl Display for ISOWeekDate

Source

impl Display for vortex::session::registry::Id

Source

impl Display for tokio::runtime::task::id::Id

Source

impl Display for tokio::runtime::id::Id

Source

impl Display for InMemory

1.34.0 · Source

impl Display for Infallible

Source

impl Display for InlinedName

Source

impl Display for IntegerTooSmall

1.7.0 · Source

impl Display for IntoStringError

Source

impl Display for InvalidFlatbuffer

Source

impl Display for InvalidHeaderName

Source

impl Display for InvalidHeaderValue

Source

impl Display for InvalidMethod

Source

impl Display for InvalidPart

Source

impl Display for InvalidParts

Source

impl Display for InvalidSetError

Source

impl Display for InvalidStatusCode

Source

impl Display for InvalidStringList

Source

impl Display for InvalidUri

Source

impl Display for InvalidUriParts

1.7.0 · Source

impl Display for IpAddr

1.0.0 · Source

impl Display for Ipv4Addr

1.0.0 · Source

impl Display for Ipv6Addr

Writes an Ipv6Addr, conforming to the canonical style described by RFC 5952.

Source

impl Display for IsSortedOptions

Source

impl Display for JoinError

1.0.0 · Source

impl Display for JoinPathsError

Source

impl Display for icu_locale_core::extensions::transform::key::Key

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::extensions::unicode::key::Key

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Keywords

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Label

Source

impl Display for Language

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for LanguageIdentifier

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for LassoError

Source

impl Display for LassoErrorKind

1.28.0 · Source

impl Display for LayoutError

Source

impl Display for Level

Source

impl Display for LevelFilter

Source

impl Display for LikeOptions

Source

impl Display for ListData

Source

impl Display for ListScalar<'_>

Source

impl Display for ListViewData

Source

impl Display for LittleEndian

Source

impl Display for LocalFileSystem

Source

impl Display for Locale

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

1.26.0 · Source

impl Display for Location<'_>

Source

impl Display for MaskedData

Source

impl Display for regex_automata::util::search::MatchError

Source

impl Display for aho_corasick::util::error::MatchError

Source

impl Display for MaxSizeReached

Source

impl Display for Method

Source

impl Display for NaiveDate

The Display output of the naive date d is the same as d.format("%Y-%m-%d").

The string printed can be readily parsed via the parse method on str.

Example

use chrono::NaiveDate;

assert_eq!(format!("{}", NaiveDate::from_ymd_opt(2015, 9, 5).unwrap()), "2015-09-05");
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(0, 1, 1).unwrap()), "0000-01-01");
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(9999, 12, 31).unwrap()), "9999-12-31");

ISO 8601 requires an explicit sign for years before 1 BCE or after 9999 CE.

assert_eq!(format!("{}", NaiveDate::from_ymd_opt(-1, 1, 1).unwrap()), "-0001-01-01");
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(10000, 12, 31).unwrap()), "+10000-12-31");
Source

impl Display for NaiveDateTime

The Display output of the naive date and time dt is the same as dt.format("%Y-%m-%d %H:%M:%S%.f").

It should be noted that, for leap seconds not on the minute boundary, it may print a representation not distinguishable from non-leap seconds. This doesn’t matter in practice, since such leap seconds never happened. (By the time of the first leap second on 1972-06-30, every time zone offset around the world has standardized to the 5-minute alignment.)

Example

use chrono::NaiveDate;

let dt = NaiveDate::from_ymd_opt(2016, 11, 15).unwrap().and_hms_opt(7, 39, 24).unwrap();
assert_eq!(format!("{}", dt), "2016-11-15 07:39:24");

Leap seconds may also be used.

let dt =
    NaiveDate::from_ymd_opt(2015, 6, 30).unwrap().and_hms_milli_opt(23, 59, 59, 1_500).unwrap();
assert_eq!(format!("{}", dt), "2015-06-30 23:59:60.500");
Source

impl Display for NaiveTime

The Display output of the naive time t is the same as t.format("%H:%M:%S%.f").

The string printed can be readily parsed via the parse method on str.

It should be noted that, for leap seconds not on the minute boundary, it may print a representation not distinguishable from non-leap seconds. This doesn’t matter in practice, since such leap seconds never happened. (By the time of the first leap second on 1972-06-30, every time zone offset around the world has standardized to the 5-minute alignment.)

Example

use chrono::NaiveTime;

assert_eq!(format!("{}", NaiveTime::from_hms_opt(23, 56, 4).unwrap()), "23:56:04");
assert_eq!(
    format!("{}", NaiveTime::from_hms_milli_opt(23, 56, 4, 12).unwrap()),
    "23:56:04.012"
);
assert_eq!(
    format!("{}", NaiveTime::from_hms_micro_opt(23, 56, 4, 1234).unwrap()),
    "23:56:04.001234"
);
assert_eq!(
    format!("{}", NaiveTime::from_hms_nano_opt(23, 56, 4, 123456).unwrap()),
    "23:56:04.000123456"
);

Leap seconds may also be used.

assert_eq!(
    format!("{}", NaiveTime::from_hms_milli_opt(6, 59, 59, 1_500).unwrap()),
    "06:59:60.500"
);
Source

impl Display for NonNilUuid

Source

impl Display for NonSortedIntegers

Source

impl Display for NormalizeError

1.0.0 · Source

impl Display for NulError

Source

impl Display for NullPtrError

Source

impl Display for Nullability

Source

impl Display for Number

Source

impl Display for NumericOperator

Source

impl Display for Offset

Source

impl Display for OnPairData

Source

impl Display for Operator

Source

impl Display for OsError

Source

impl Display for Other

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for OutOfRange

Source

impl Display for OutOfRangeError

Source

impl Display for PType

Source

impl Display for PValue

Source

impl Display for PackOptions

1.26.0 · Source

impl Display for PanicHookInfo<'_>

1.26.0 · Source

impl Display for PanicInfo<'_>

1.81.0 · Source

impl Display for PanicMessage<'_>

Source

impl Display for ParseAlphabetError

Source

impl Display for ParseBigIntError

1.0.0 · Source

impl Display for ParseBoolError

1.20.0 · Source

impl Display for ParseCharError

Source

impl Display for bitflags::parser::ParseError

Source

impl Display for chrono::format::ParseError

Source

impl Display for url::parser::ParseError

Source

impl Display for icu_locale_core::parser::errors::ParseError

Source

impl Display for tinystr::error::ParseError

1.0.0 · Source

impl Display for core::num::float_parse::ParseFloatError

Source

impl Display for num_traits::ParseFloatError

1.0.0 · Source

impl Display for ParseIntError

Source

impl Display for ParseLevelError

Source

impl Display for ParseLevelFilterError

Source

impl Display for ParseMonthError

Source

impl Display for ParseWeekdayError

Source

impl Display for PatchedData

Source

impl Display for Path

Source

impl Display for PathAndQuery

Source

impl Display for Pattern

Show the original glob pattern.

Source

impl Display for PatternError

Source

impl Display for regex_automata::util::primitives::PatternIDError

Source

impl Display for aho_corasick::util::primitives::PatternIDError

Source

impl Display for PatternSetInsertError

Available on crate feature alloc only.
Source

impl Display for PcoData

Source

impl Display for PcoError

Source

impl Display for PercentEncode<'_>

Source

impl Display for Pid

Source

impl Display for PodCastError

Available on non-SPIR-V only.
Source

impl Display for PoolTable

Source

impl Display for PopError

Source

impl Display for PredicateError

Source

impl Display for PreferencesParseError

Source

impl Display for PrimitiveData

Source

impl Display for PrimitiveScalar<'_>

Source

impl Display for Private

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for RLEData

Source

impl Display for RangeError

Source

impl Display for ReceiveError

Source

impl Display for ReceiveErrorTimeout

1.0.0 · Source

impl Display for std::sync::mpsc::RecvError

Source

impl Display for futures_channel::mpsc::RecvError

Source

impl Display for tokio::sync::broadcast::error::RecvError

Source

impl Display for tokio::sync::oneshot::error::RecvError

Source

impl Display for tokio::sync::watch::error::RecvError

Source

impl Display for async_channel::RecvError

Source

impl Display for oneshot::errors::RecvError

Available on crate features async or std only.
Source

impl Display for crossbeam_channel::err::RecvError

1.15.0 · Source

impl Display for std::sync::mpsc::RecvTimeoutError

Source

impl Display for crossbeam_channel::err::RecvTimeoutError

Source

impl Display for regex::regex::bytes::Regex

Source

impl Display for regex::regex::string::Regex

Source

impl Display for Region

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for RoundingError

Source

impl Display for RunEndData

Source

impl Display for Scalar

Source

impl Display for ScalarFnOptions<'_>

Source

impl Display for ScalarFnRef

Source

impl Display for ScalarValue

Source

impl Display for Schema

Source

impl Display for Scheme

Source

impl Display for SchemeId

Source

impl Display for Script

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for SearchResult

Source

impl Display for SearchSortedSide

Source

impl Display for SegmentId

Source

impl Display for SelectTimeoutError

Source

impl Display for futures_channel::mpsc::SendError

Source

impl Display for kanal::error::SendError

Source

impl Display for SendErrorTimeout

Source

impl Display for SequenceData

Source

impl Display for SerializeError

Source

impl Display for SetGlobalDefaultError

Source

impl Display for SharedData

Source

impl Display for SignedDuration

Source

impl Display for Simple

Source

impl Display for SliceData

Source

impl Display for SmallIndexError

1.0.0 · Source

impl Display for SocketAddr

1.0.0 · Source

impl Display for SocketAddrV4

1.0.0 · Source

impl Display for SocketAddrV6

Source

impl Display for SorfOptions

Source

impl Display for SortOptions

Source

impl Display for Span

Source

impl Display for SparseData

Source

impl Display for SpawnError

Source

impl Display for StartError

Source

impl Display for Stat

Source

impl Display for StatOptions

Source

impl Display for regex_automata::util::primitives::StateIDError

Source

impl Display for aho_corasick::util::primitives::StateIDError

Source

impl Display for StatusCode

Formats the status code, including the canonical reason.

Example

assert_eq!(format!("{}", StatusCode::OK), "200 OK");
1.0.0 · Source

impl Display for String

Source

impl Display for StringEscape<'_>

1.7.0 · Source

impl Display for StripPrefixError

Source

impl Display for StructFields

Source

impl Display for StructScalar<'_>

Source

impl Display for SubdivisionId

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for SubdivisionSuffix

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::extensions::private::other::Subtag

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::subtags::Subtag

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for SyntaxViolation

1.8.0 · Source

impl Display for SystemTimeError

Source

impl Display for Table

Source

impl Display for TemporalJiff

Source

impl Display for Time

Converts a Time into an ISO 8601 compliant string.

Formatting options supported

  • std::fmt::Formatter::precision can be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.

Example

use jiff::civil::time;

// No fractional seconds:
let t = time(7, 0, 0, 0);
assert_eq!(format!("{t}"), "07:00:00");

// With fractional seconds:
let t = time(7, 0, 0, 123_000_000);
assert_eq!(format!("{t}"), "07:00:00.123");

Example: setting the precision

use jiff::civil::time;

let t = time(7, 0, 0, 123_000_000);
assert_eq!(format!("{t:.6}"), "07:00:00.123000");
// Precision values greater than 9 are clamped to 9.
assert_eq!(format!("{t:.300}"), "07:00:00.123000000");
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(format!("{t:.0}"), "07:00:00");
Source

impl Display for TimeDelta

Source

impl Display for vortex::extension::datetime::TimeUnit

Source

impl Display for arrow_schema::datatype::TimeUnit

Source

impl Display for TimeValue

Source

impl Display for jiff::timestamp::Timestamp

Converts a Timestamp datetime into a RFC 3339 compliant string.

Since a Timestamp never has an offset associated with it and is always in UTC, the string emitted by this trait implementation uses Z for “Zulu” time. The significance of Zulu time is prescribed by RFC 9557 and means that “the time in UTC is known, but the offset to local time is unknown.” If you need to emit an RFC 3339 compliant string with a specific offset, then use Timestamp::display_with_offset.

Formatting options supported

  • std::fmt::Formatter::precision can be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.

Example

This shows the default rendering:

use jiff::Timestamp;

// No fractional seconds.
let ts = Timestamp::from_second(1_123_456_789)?;
assert_eq!(format!("{ts}"), "2005-08-07T23:19:49Z");

// With fractional seconds.
let ts = Timestamp::new(1_123_456_789, 123_000_000)?;
assert_eq!(format!("{ts}"), "2005-08-07T23:19:49.123Z");

Example: setting the precision

use jiff::Timestamp;

let ts = Timestamp::new(1_123_456_789, 123_000_000)?;
assert_eq!(
    format!("{ts:.6}"),
    "2005-08-07T23:19:49.123000Z",
);
// Precision values greater than 9 are clamped to 9.
assert_eq!(
    format!("{ts:.300}"),
    "2005-08-07T23:19:49.123000000Z",
);
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(
    format!("{ts:.0}"),
    "2005-08-07T23:19:49Z",
);
Source

impl Display for prost_types::protobuf::Timestamp

Source

impl Display for TimestampDisplayWithOffset

Source

impl Display for TimestampError

Source

impl Display for TimestampOptions

Source

impl Display for TimestampValue<'_>

1.16.0 · Source

impl Display for ToLowercase

Source

impl Display for ToStrError

Source

impl Display for ToTitlecase

1.16.0 · Source

impl Display for ToUppercase

Source

impl Display for Transform

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for TreeDisplay

Source

impl Display for TryAcquireError

Source

impl Display for TryCurrentError

1.59.0 · Source

impl Display for TryFromCharError

1.66.0 · Source

impl Display for TryFromFloatSecsError

1.34.0 · Source

impl Display for TryFromIntError

1.35.0 · Source

impl Display for TryFromSliceError

Source

impl Display for TryGetError

1.89.0 · Source

impl Display for std::fs::TryLockError

Source

impl Display for tokio::sync::mutex::TryLockError

1.0.0 · Source

impl Display for std::sync::mpsc::TryRecvError

Source

impl Display for futures_channel::mpsc::TryRecvError

Source

impl Display for tokio::sync::broadcast::error::TryRecvError

Source

impl Display for tokio::sync::mpsc::error::TryRecvError

Source

impl Display for tokio::sync::oneshot::error::TryRecvError

Source

impl Display for async_channel::TryRecvError

Source

impl Display for oneshot::errors::TryRecvError

Source

impl Display for crossbeam_channel::err::TryRecvError

1.57.0 · Source

impl Display for vortex::array::smallvec::alloc::collections::TryReserveError

Source

impl Display for allocator_api2::stable::raw_vec::TryReserveError

Source

impl Display for hashbrown::TryReserveError

Source

impl Display for TrySelectError

Source

impl Display for TzOffset

Source

impl Display for Uid

Source

impl Display for UleError

Source

impl Display for Unicode

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for UnicodeWordBoundaryError

Source

impl Display for UnicodeWordError

Source

impl Display for UnknownEnumValue

Source

impl Display for UnorderedKeyError

Source

impl Display for Uri

Source

impl Display for Url

Display the serialization of this URL.

Source

impl Display for Urn

Source

impl Display for Utc

Source

impl Display for Utf8CharsError

1.0.0 · Source

impl Display for vortex::array::smallvec::alloc::str::Utf8Error

Source

impl Display for simdutf8::basic::Utf8Error

Source

impl Display for simdutf8::compat::Utf8Error

Source

impl Display for Utf8Scalar<'_>

Source

impl Display for Uuid

Source

impl Display for UuidMetadata

Source

impl Display for serde_json::value::Value

Source

impl Display for icu_locale_core::extensions::transform::value::Value

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::extensions::unicode::value::Value

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for ValueFormatter<'_>

Source

impl Display for ValueSet<'_>

Source

impl Display for VarBinData

Source

impl Display for VarBinViewData

1.0.0 · Source

impl Display for VarError

Source

impl Display for icu_locale_core::subtags::variant::Variant

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for uuid::Variant

Source

impl Display for VariantGetOptions

Source

impl Display for VariantPath

Source

impl Display for VariantScalar<'_>

Source

impl Display for Variants

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for VortexError

Source

impl Display for Weekday

Source

impl Display for WeekdaySet

Print the collection as a slice-like list of weekdays.

Example

use chrono::Weekday::*;
assert_eq!("[]", WeekdaySet::EMPTY.to_string());
assert_eq!("[Mon]", WeekdaySet::single(Mon).to_string());
assert_eq!("[Mon, Fri, Sun]", WeekdaySet::from_array([Mon, Fri, Sun]).to_string());
Source

impl Display for WouldBlock

1.56.0 · Source

impl Display for WriterPanicked

Source

impl Display for ZeroTrieBuildError

Source

impl Display for ZigZagData

Source

impl Display for Zoned

Converts a Zoned datetime into a RFC 9557 compliant string.

Formatting options supported

  • std::fmt::Formatter::precision can be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.

Example

This shows the default rendering:

use jiff::civil::date;

// No fractional seconds:
let zdt = date(2024, 6, 15).at(7, 0, 0, 0).in_tz("US/Eastern")?;
assert_eq!(format!("{zdt}"), "2024-06-15T07:00:00-04:00[US/Eastern]");

// With fractional seconds:
let zdt = date(2024, 6, 15).at(7, 0, 0, 123_000_000).in_tz("US/Eastern")?;
assert_eq!(format!("{zdt}"), "2024-06-15T07:00:00.123-04:00[US/Eastern]");

Example: setting the precision

use jiff::civil::date;

let zdt = date(2024, 6, 15).at(7, 0, 0, 123_000_000).in_tz("US/Eastern")?;
assert_eq!(
    format!("{zdt:.6}"),
    "2024-06-15T07:00:00.123000-04:00[US/Eastern]",
);
// Precision values greater than 9 are clamped to 9.
assert_eq!(
    format!("{zdt:.300}"),
    "2024-06-15T07:00:00.123000000-04:00[US/Eastern]",
);
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(
    format!("{zdt:.0}"),
    "2024-06-15T07:00:00-04:00[US/Eastern]",
);
Source

impl Display for ZstdBuffersData

Source

impl Display for ZstdData

Source

impl Display for bf16

Available on non-SPIR-V only.
1.0.0 · Source

impl Display for bool

1.0.0 · Source

impl Display for char

Source

impl Display for dyn Expected + '_

Source

impl Display for dyn Layout + '_

Display the encoding, dtype, row count, and segment IDs of this layout.

Source

impl Display for dyn LayoutEncoding + '_

Source

impl Display for dyn Value

1.0.0 · Source

impl Display for f16

Source

impl Display for f16

Available on non-SPIR-V only.
1.0.0 · Source

impl Display for f32

1.0.0 · Source

impl Display for f64

1.0.0 · Source

impl Display for i8

1.0.0 · Source

impl Display for i16

1.0.0 · Source

impl Display for i32

1.0.0 · Source

impl Display for i64

1.0.0 · Source

impl Display for i128

Source

impl Display for vortex::dtype::i256

Source

impl Display for arrow_buffer::bigint::i256

1.0.0 · Source

impl Display for isize

1.0.0 · Source

impl Display for str

1.0.0 · Source

impl Display for u8

1.0.0 · Source

impl Display for u16

1.0.0 · Source

impl Display for u32

1.0.0 · Source

impl Display for u64

1.0.0 · Source

impl Display for u128

1.0.0 · Source

impl Display for usize

Source

impl<'a, 'e, E> Display for Base64Display<'a, 'e, E>
where E: Engine,

Source

impl<'a, I, B> Display for DelayedFormat<I>
where I: Iterator<Item = B> + Clone, B: Borrow<Item<'a>>,

Available on crate feature alloc only.
Source

impl<'a, I> Display for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Display,

Source

impl<'a, K, V, S, A> Display for hashbrown::map::OccupiedError<'a, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,

Source

impl<'a, R, G, T> Display for MappedReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, G, T> Display for ReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::mutex::MappedMutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::MappedRwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::MappedRwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::mutex::MutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::RwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::RwLockUpgradableReadGuard<'a, R, T>
where R: RawRwLockUpgrade + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::RwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, T, O> Display for Domain<'a, Const, T, O>
where O: BitOrder, T: BitStore,

Source

impl<'a, T> Display for tokio::sync::mutex::MappedMutexGuard<'a, T>
where T: Display + ?Sized,

Source

impl<'a, T> Display for RwLockMappedWriteGuard<'a, T>
where T: Display + ?Sized,

Source

impl<'a, T> Display for tokio::sync::rwlock::read_guard::RwLockReadGuard<'a, T>
where T: Display + ?Sized,

Source

impl<'a, T> Display for tokio::sync::rwlock::write_guard::RwLockWriteGuard<'a, T>
where T: Display + ?Sized,

1.60.0 · Source

impl<'a> Display for EscapeAscii<'a>

1.34.0 · Source

impl<'a> Display for vortex::array::smallvec::alloc::str::EscapeDebug<'a>

1.34.0 · Source

impl<'a> Display for vortex::array::smallvec::alloc::str::EscapeDefault<'a>

1.34.0 · Source

impl<'a> Display for vortex::array::smallvec::alloc::str::EscapeUnicode<'a>

Source

impl<'a> Display for Unexpected<'a>

Source

impl<'d> Display for TimeZoneName<'d>

Source

impl<'f> Display for jiff::fmt::strtime::Display<'f>

Source

impl<'n> Display for Pieces<'n>

Source

impl<A, B> Display for Concat<A, B>
where A: Writeable, B: Writeable,

Source

impl<A, O> Display for BitArray<A, O>
where O: BitOrder, A: BitViewSized,

Source

impl<A, S, V> Display for ConvertError<A, S, V>
where A: Display, S: Display, V: Display,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<A> Display for PartitionedExpr<A>
where A: Display,

Source

impl<B> Display for bit_vec::BitVec<B>
where B: BitBlock,

1.0.0 · Source

impl<B> Display for Cow<'_, B>
where B: Display + ToOwned + ?Sized, <B as ToOwned>::Owned: Display,

Source

impl<D> Display for PrecisionScale<D>

Source

impl<D> Display for Tree<D>
where D: Display,

Source

impl<E> Display for ParseComplexError<E>
where E: Display,

Source

impl<E> Display for Report<E>
where E: Error,

Source

impl<Enum> Display for TryFromPrimitiveError<Enum>
where Enum: TryFromPrimitive,

1.93.0 · Source

impl<F> Display for FromFn<F>
where F: Fn(&mut Formatter<'_>) -> Result<(), Error>,

Source

impl<I, F> Display for FormatWith<'_, I, F>
where I: Iterator, F: FnMut(<I as Iterator>::Item, &mut dyn FnMut(&dyn Display) -> Result<(), Error>) -> Result<(), Error>,

Source

impl<I> Display for ExactlyOneError<I>
where I: Iterator,

Source

impl<K, V, S, A> Display for hashbrown::map::OccupiedError<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,

Source

impl<K, V, S, A> Display for hashbrown::map::OccupiedError<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,

Source

impl<K, V, T> Display for MappedRef<'_, K, V, T>
where K: Eq + Hash, T: Display,

Source

impl<L, R> Display for Either<L, R>
where L: Display, R: Display,

Source

impl<L, R> Display for PairOptions<L, R>
where L: Display, R: Display,

Source

impl<M, T, O> Display for BitRef<'_, M, T, O>
where M: Mutability, T: BitStore, O: BitOrder,

Available on non-tarpaulin_include only.
Source

impl<O> Display for F32<O>
where O: ByteOrder,

Source

impl<O> Display for F64<O>
where O: ByteOrder,

Source

impl<O> Display for I16<O>
where O: ByteOrder,

Source

impl<O> Display for I32<O>
where O: ByteOrder,

Source

impl<O> Display for I64<O>
where O: ByteOrder,

Source

impl<O> Display for I128<O>
where O: ByteOrder,

Source

impl<O> Display for Isize<O>
where O: ByteOrder,

Source

impl<O> Display for U16<O>
where O: ByteOrder,

Source

impl<O> Display for U32<O>
where O: ByteOrder,

Source

impl<O> Display for U64<O>
where O: ByteOrder,

Source

impl<O> Display for U128<O>
where O: ByteOrder,

Source

impl<O> Display for Usize<O>
where O: ByteOrder,

1.33.0 · Source

impl<Ptr> Display for Pin<Ptr>
where Ptr: Display,

Source

impl<R, D, G, C> Display for CompactGrid<R, D, G, C>
where &'a R: for<'a> Records, <<&'a R as Records>::Iter as IntoRecords>::Cell: for<'a> AsRef<str>, D: Dimension, G: Borrow<CompactConfig>, C: Colors,

Source

impl<R, G, D, C> Display for PeekableGrid<R, G, D, C>

Source

impl<R> Display for BitEnd<R>
where R: BitRegister,

Source

impl<R> Display for BitIdx<R>
where R: BitRegister,

Source

impl<R> Display for BitIdxError<R>
where R: BitRegister,

Available on non-tarpaulin_include only.
Source

impl<R> Display for BitMask<R>
where R: BitRegister,

Source

impl<R> Display for BitPos<R>
where R: BitRegister,

Source

impl<R> Display for BitSel<R>
where R: BitRegister,

Source

impl<S> Display for Host<S>
where S: AsRef<str>,

Source

impl<S> Display for Text<S>
where S: Display,

Source

impl<Src, Dst> Display for AlignmentError<Src, Dst>
where Src: Deref, Dst: KnownLayout + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<Src, Dst> Display for SizeError<Src, Dst>
where Src: Deref, Dst: KnownLayout + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<Src, Dst> Display for ValidityError<Src, Dst>
where Dst: KnownLayout + TryFromBytes + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

1.0.0 · Source

impl<T, A> Display for Arc<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for vortex::array::smallvec::alloc::boxed::Box<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for allocator_api2::stable::boxed::Box<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Rc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueArc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueRc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, B> Display for zerocopy::ref::def::Ref<B, T>

Source

impl<T, E> Display for TryChunksError<T, E>
where E: Display,

Source

impl<T, E> Display for TryReadyChunksError<T, E>
where E: Display,

Source

impl<T, Item> Display for futures_util::stream::stream::split::ReuniteError<T, Item>

Source

impl<T, O> Display for BitBox<T, O>
where O: BitOrder, T: BitStore,

Source

impl<T, O> Display for BitSlice<T, O>
where T: BitStore, O: BitOrder,

Source

impl<T, O> Display for bitvec::vec::BitVec<T, O>
where O: BitOrder, T: BitStore,

Source

impl<T, O> Display for ISizeFormatter<T, O>

Source

impl<T, O> Display for SizeFormatter<T, O>

Source

impl<T, S> Display for ArcSwapAny<T, S>
where S: Strategy<T>, T: Display + RefCnt,

Source

impl<T, S> Display for Guard<T, S>
where T: Display + RefCnt, S: Strategy<T>,

Source

impl<T, U> Display for OwnedMappedMutexGuard<T, U>
where U: Display + ?Sized, T: ?Sized,

Source

impl<T, U> Display for OwnedRwLockMappedWriteGuard<T, U>
where U: Display + ?Sized, T: ?Sized,

Source

impl<T, U> Display for OwnedRwLockReadGuard<T, U>
where U: Display + ?Sized, T: ?Sized,

1.0.0 · Source

impl<T> Display for &T
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for &mut T
where T: Display + ?Sized,

Source

impl<T> Display for ArcRef<T>
where T: 'static + Display + ?Sized,

Source

impl<T> Display for BitPtrError<T>
where T: BitStore,

Available on non-tarpaulin_include only.
Source

impl<T> Display for BitSpanError<T>
where T: BitStore,

Available on non-tarpaulin_include only.
Source

impl<T> Display for CachePadded<T>
where T: Display,

Source

impl<T> Display for Compat<T>
where T: ObjectStore,

Source

impl<T> Display for Complex<T>
where T: Display + Num + PartialOrd + Clone,

Source

impl<T> Display for DisplayValue<T>
where T: Display,

Source

impl<T> Display for FmtBinary<T>
where T: Binary + Display,

Available on non-tarpaulin_include only.
Source

impl<T> Display for FmtDisplay<T>
where T: Display,

Available on non-tarpaulin_include only.
Source

impl<T> Display for FmtList<T>
where &'a T: for<'a> IntoIterator, <&'a T as IntoIterator>::Item: for<'a> Display,

Source

impl<T> Display for FmtLowerExp<T>
where T: LowerExp + Display,

Available on non-tarpaulin_include only.
Source

impl<T> Display for FmtLowerHex<T>
where T: LowerHex + Display,

Available on non-tarpaulin_include only.
Source

impl<T> Display for FmtOctal<T>
where T: Octal + Display,

Available on non-tarpaulin_include only.
Source

impl<T> Display for FmtPointer<T>
where T: Pointer + Display,

Available on non-tarpaulin_include only.
Source

impl<T> Display for FmtUpperExp<T>
where T: UpperExp + Display,

Available on non-tarpaulin_include only.
Source

impl<T> Display for FmtUpperHex<T>
where T: UpperHex + Display,

Available on non-tarpaulin_include only.
Source

impl<T> Display for ForcePushError<T>

Source

impl<T> Display for LimitStore<T>
where T: ObjectStore,

Source

impl<T> Display for LossyWrap<T>
where T: TryWriteable,

Source

impl<T> Display for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for MisalignError<T>

Available on non-tarpaulin_include only.
Source

impl<T> Display for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for tokio::sync::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for async_lock::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for MutexGuardArc<T>
where T: Display + ?Sized,

1.28.0 · Source

impl<T> Display for NonZero<T>

Source

impl<T> Display for OwnedMutexGuard<T>
where T: Display + ?Sized,

Source

impl<T> Display for OwnedRwLockWriteGuard<T>
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for PoisonError<T>

Source

impl<T> Display for Port<T>

Source

impl<T> Display for Precision<T>
where T: Display,

Source

impl<T> Display for PrefixStore<T>

Source

impl<T> Display for PushError<T>

Source

impl<T> Display for std::sync::oneshot::RecvTimeoutError<T>

Source

impl<T> Display for ReentrantLockGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for core::cell::Ref<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for RefMut<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for futures_util::io::split::ReuniteError<T>

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for async_lock::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for RwLockReadGuardArc<T>
where T: Display,

Source

impl<T> Display for async_lock::rwlock::RwLockUpgradableReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for RwLockUpgradableReadGuardArc<T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for async_lock::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for RwLockWriteGuardArc<T>
where T: Display + ?Sized,

1.74.0 · Source

impl<T> Display for Saturating<T>
where T: Display,

1.0.0 · Source

impl<T> Display for std::sync::mpsc::SendError<T>

Source

impl<T> Display for tokio::sync::broadcast::error::SendError<T>

Source

impl<T> Display for tokio::sync::mpsc::error::SendError<T>

Source

impl<T> Display for tokio::sync::watch::error::SendError<T>

Source

impl<T> Display for async_channel::SendError<T>

Source

impl<T> Display for oneshot::errors::SendError<T>

Source

impl<T> Display for crossbeam_channel::err::SendError<T>

Source

impl<T> Display for std::sync::mpmc::error::SendTimeoutError<T>

Source

impl<T> Display for tokio::sync::mpsc::error::SendTimeoutError<T>

Available on crate feature time only.
Source

impl<T> Display for crossbeam_channel::err::SendTimeoutError<T>

Source

impl<T> Display for SetError<T>

Source

impl<T> Display for SetOnceError<T>

Source

impl<T> Display for ShardedLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for ShardedLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for ThinBox<T>
where T: Display + ?Sized,

Source

impl<T> Display for ThrottledStore<T>
where T: ObjectStore,

Source

impl<T> Display for TryFromBigIntError<T>

1.0.0 · Source

impl<T> Display for std::sync::poison::TryLockError<T>

Source

impl<T> Display for std::sync::oneshot::TryRecvError<T>

1.0.0 · Source

impl<T> Display for std::sync::mpsc::TrySendError<T>

Source

impl<T> Display for futures_channel::mpsc::TrySendError<T>

Source

impl<T> Display for tokio::sync::mpsc::error::TrySendError<T>

Source

impl<T> Display for async_channel::TrySendError<T>

Source

impl<T> Display for crossbeam_channel::err::TrySendError<T>

Source

impl<T> Display for TryWriteableInfallibleAsWriteable<T>
where T: TryWriteable<Error = Infallible>,

Source

impl<T> Display for Unalign<T>
where T: Unaligned + Display,

Source

impl<T> Display for WithPart<T>
where T: Writeable + ?Sized,

1.10.0 · Source

impl<T> Display for Wrapping<T>
where T: Display,

Source

impl<Tz> Display for chrono::date::Date<Tz>
where Tz: TimeZone, <Tz as TimeZone>::Offset: Display,

Source

impl<Tz> Display for chrono::datetime::DateTime<Tz>
where Tz: TimeZone, <Tz as TimeZone>::Offset: Display,

1.0.0 · Source

impl<W> Display for IntoInnerError<W>

Source

impl<Y, C> Display for Yoke<Y, C>
where Y: for<'a> Yokeable<'a>, <Y as Yokeable<'a>>::Output: for<'a> Display,

Source

impl<const N: usize> Display for TinyAsciiStr<N>