Trait TakeFn

pub trait TakeFn {
    // Required method
    fn take(&self, indices: &Array) -> Result<Array, VortexError>;
}

Required Methods

fn take(&self, indices: &Array) -> Result<Array, VortexError>

Implementations on Foreign Types

Source

impl TakeFn for ALPArray

Source

fn take(&self, indices: &Array) -> Result<Array, VortexError>

Source

impl TakeFn for ALPRDArray

Source

fn take(&self, indices: &Array) -> Result<Array, VortexError>

Source

impl TakeFn for ByteBoolArray

Source

fn take(&self, indices: &Array) -> Result<Array, VortexError>

Source

impl TakeFn for DateTimePartsArray

Source

fn take(&self, indices: &Array) -> Result<Array, VortexError>

Source

impl TakeFn for DictArray

Source

fn take(&self, indices: &Array) -> Result<Array, VortexError>

Source

impl TakeFn for BitPackedArray

Source

fn take(&self, indices: &Array) -> Result<Array, VortexError>

Source

impl TakeFn for FoRArray

Source

fn take(&self, indices: &Array) -> Result<Array, VortexError>

Source

impl TakeFn for FSSTArray

Source

fn take(&self, indices: &Array) -> Result<Array, VortexError>

Source

impl TakeFn for RunEndBoolArray

Source

fn take(&self, indices: &Array) -> Result<Array, VortexError>

Source

impl TakeFn for RunEndArray

Source

fn take(&self, indices: &Array) -> Result<Array, VortexError>

Implementors

Source

impl TakeFn for BoolArray

Source

impl TakeFn for ChunkedArray

Source

impl TakeFn for ConstantArray

Source

impl TakeFn for ExtensionArray

Source

impl TakeFn for NullArray

Source

impl TakeFn for PrimitiveArray

Source

impl TakeFn for SparseArray

Source

impl TakeFn for StructArray

Source

impl TakeFn for VarBinArray

Source

impl TakeFn for VarBinViewArray

Take involves creating a new array that references the old array, just with the given set of views.