pub struct ExtDTypeRef(/* private fields */);Expand description
A type-erased extension dtype.
This stores an ExtVTable, some type metadata, and a storage DType behind a trait object,
allowing heterogeneous storage inside DType::Extension (so that we do not need a generic
parameter).
You can use try_downcast() or downcast() to recover the concrete vtable type as an
ExtDType<V> (as long as you know what V is).
Implementations
Sourceimpl ExtDTypeRef
impl ExtDTypeRef
Sourcepub fn storage_dtype(&self) -> &DType
pub fn storage_dtype(&self) -> &DType
Returns the storage dtype of the extension type.
Sourcepub fn nullability(&self) -> Nullability
pub fn nullability(&self) -> Nullability
Returns the nullability of the storage dtype.
Sourcepub fn is_nullable(&self) -> bool
pub fn is_nullable(&self) -> bool
Returns true if the storage dtype is nullable.
Sourcepub fn with_nullability(&self, nullability: Nullability) -> ExtDTypeRef
pub fn with_nullability(&self, nullability: Nullability) -> ExtDTypeRef
Returns a new ExtDTypeRef with the given nullability.
Sourcepub fn eq_ignore_nullability(&self, other: &ExtDTypeRef) -> bool
pub fn eq_ignore_nullability(&self, other: &ExtDTypeRef) -> bool
Compute equality ignoring nullability.
Sourcepub fn serialize_metadata(&self) -> Result<Vec<u8>, VortexError>
pub fn serialize_metadata(&self) -> Result<Vec<u8>, VortexError>
Serialize the metadata into a byte vector.
Sourcepub fn display_metadata(&self) -> impl Display
pub fn display_metadata(&self) -> impl Display
Returns a Display-able view of just the metadata.
Sourcepub fn can_coerce_from(&self, other: &DType) -> bool
pub fn can_coerce_from(&self, other: &DType) -> bool
Can a value of other be implicitly coerced into this extension type?
Sourcepub fn can_coerce_to(&self, other: &DType) -> bool
pub fn can_coerce_to(&self, other: &DType) -> bool
Can this extension type be implicitly coerced into other?
Sourcepub fn least_supertype(&self, other: &DType) -> Option<DType>
pub fn least_supertype(&self, other: &DType) -> Option<DType>
Compute the least supertype of this extension type and another type.
Sourceimpl ExtDTypeRef
Methods for downcasting type-erased extension dtypes.
impl ExtDTypeRef
Methods for downcasting type-erased extension dtypes.
Sourcepub fn is<M>(&self) -> boolwhere
M: Matcher,
pub fn is<M>(&self) -> boolwhere
M: Matcher,
Check if the extension dtype is of the concrete type.
Sourcepub fn metadata_opt<M>(&self) -> Option<<M as Matcher>::Match<'_>>where
M: Matcher,
pub fn metadata_opt<M>(&self) -> Option<<M as Matcher>::Match<'_>>where
M: Matcher,
Extract the metadata of the ExtDType per the given Matcher.
Sourcepub fn try_downcast<V>(self) -> Result<Arc<ExtDType<V>>, ExtDTypeRef>where
V: ExtVTable,
pub fn try_downcast<V>(self) -> Result<Arc<ExtDType<V>>, ExtDTypeRef>where
V: ExtVTable,
Downcast to the concrete ExtDType.
Returns Err(self) if the downcast fails.