Traits and types to define shared unique encoding identifiers.
Modules
Structs
- Encoding
Id - EncodingId is a unique name and numerical code of the array
Traits
- Array
Encoding - Object-safe encoding trait for an array.
- Array
Encoding Ext - Non-object-safe extensions to the ArrayEncoding trait.
- Array
Encoding Ref