Module io

Module io 

Modules

compat
Compatibility layer similar to Rust async-compat that allows non-Tokio runtimes to use Tokio-based implementations of the core traits, such as the ObjectStore implementations.
filesystem
A filesystem abstraction for discovering and opening Vortex files.
kanal_ext
object_store
runtime
A Vortex runtime provides an abstract way of scheduling mixed I/O and CPU workloads onto the various threading models supported by Vortex.
session
std_file

Structs

AsyncWriteAdapter
An adapter to use an AsyncWrite as a VortexWrite.
CoalesceConfig
Configuration for coalescing nearby I/O requests into single operations.
InstrumentedReadAt
A wrapper that instruments a VortexReadAt with metrics.
OwnedSlice
An owned view into a contiguous sequence of bytes.
SizeLimitedStream
A Stream that can work on several simultaneous requests, capping the amount of memory it uses at any given point.

Traits

IoBuf
Trait for types that can provide a readonly byte buffer interface to I/O frameworks.
VortexReadAt
The unified read trait for Vortex I/O sources.
VortexWrite