ScalarValue

Enum ScalarValue 

pub enum ScalarValue {
    Bool(bool),
    Primitive(PValue),
    Decimal(DecimalValue),
    Utf8(BufferString),
    Binary(Buffer<u8>),
    Tuple(Vec<Option<ScalarValue>>),
    Variant(Box<Scalar>),
}
The value stored in a Scalar.

This enum represents the possible non-null values that can be stored in a scalar. When the scalar is null, the value is represented as None in the Option<ScalarValue> field.

Variants



Bool(bool)

A boolean value.



Primitive(PValue)

A primitive numeric value.



Decimal(DecimalValue)

A decimal value.



Utf8(BufferString)

A UTF-8 encoded string value.



Binary(Buffer<u8>)

A binary (byte array) value.



Tuple(Vec<Option<ScalarValue>>)

A tuple of potentially null scalar values.

Used as the underlying representation for list, fixed-size list, and struct scalars.



Variant(Box<Scalar>)

A row-specific scalar wrapped by DType::Variant.

Implementations

Source

impl ScalarValue

pub fn as_bool(&self) -> bool

Returns the boolean value, panicking if the value is not a Bool.

pub fn as_primitive(&self) -> &PValue

Returns the primitive value, panicking if the value is not a Primitive.

pub fn as_decimal(&self) -> &DecimalValue

Returns the decimal value, panicking if the value is not a Decimal.

pub fn as_utf8(&self) -> &BufferString

Returns the UTF-8 string value, panicking if the value is not a Utf8.

pub fn as_binary(&self) -> &Buffer<u8>

Returns the binary value, panicking if the value is not a Binary.

pub fn as_list(&self) -> &[Option<ScalarValue>]

Returns the tuple elements, panicking if the value is not a Tuple.

pub fn into_bool(self) -> bool

Returns the boolean value, panicking if the value is not a Bool.

pub fn into_primitive(self) -> PValue

Returns the primitive value, panicking if the value is not a Primitive.

pub fn into_decimal(self) -> DecimalValue

Returns the decimal value, panicking if the value is not a Decimal.

pub fn into_utf8(self) -> BufferString

Returns the UTF-8 string value, panicking if the value is not a Utf8.

pub fn into_binary(self) -> Buffer<u8>

Returns the binary value, panicking if the value is not a Binary.

pub fn into_list(self) -> Vec<Option<ScalarValue>>

Returns the tuple elements, panicking if the value is not a Tuple.

pub fn as_variant(&self) -> &Scalar

Returns the row-specific scalar wrapped by a variant, panicking if the value is not a variant.

pub fn into_variant(self) -> Scalar

Returns the row-specific scalar wrapped by a variant, panicking if the value is not a variant.

Source

impl ScalarValue

pub fn to_proto(this: Option<&ScalarValue>) -> ScalarValue

Ideally, we would not have this function and instead implement this From implementation:

impl From<Option<&ScalarValue>> for pb::ScalarValue { ... }

However, we are not allowed to do this because of the Orphan rule (Option and pb::ScalarValue are not types defined in this crate). So we must make this a method on vortex_array::scalar::ScalarValue directly.

pub fn to_proto_bytes<B>(value: Option<&ScalarValue>) -> B
where B: Default + BufMut,

Serialize an optional ScalarValue to protobuf bytes (handles null values).

Source

impl ScalarValue

pub fn from_proto_bytes( bytes: &[u8], dtype: &DType, session: &VortexSession, ) -> Result<Option<ScalarValue>, VortexError>

Deserialize a ScalarValue from protobuf bytes.

Note that we need to provide a DType since protobuf serialization only supports 64-bit integers, and serializing into protobuf loses that type information.

Errors

Returns an error if decoding or type validation fails.

pub fn from_proto( value: &ScalarValue, dtype: &DType, session: &VortexSession, ) -> Result<Option<ScalarValue>, VortexError>

Creates a ScalarValue from its protobuf representation.

Note that we need to provide a DType since protobuf serialization only supports 64-bit integers, and serializing into protobuf loses that type information.

Errors

Returns an error if the protobuf value cannot be converted to the given DType.