Re-exports
pub use vortex_alp as alp;pub use vortex_buffer as buffer;pub use vortex_bytebool as bytebool;pub use vortex_datetime_dtype as datetime_dtype;pub use vortex_datetime_parts as datetime_parts;pub use vortex_dict as dict;pub use vortex_dtype as dtype;pub use vortex_error as error;pub use vortex_expr as expr;pub use vortex_fastlanes as fastlanes;pub use vortex_flatbuffers as flatbuffers;pub use vortex_fsst as fsst;pub use vortex_proto as proto;pub use vortex_roaring as roaring;pub use vortex_runend as runend;pub use vortex_runend_bool as runend_bool;pub use vortex_sampling_compressor as sampling_compressor;pub use vortex_scalar as scalar;pub use vortex_schema as schema;pub use vortex_serde as serde;pub use vortex_zigzag as zigzag;
Modules
- accessor
- aliases
- array
- All the built-in encoding schemes and arrays.
- arrow
- Utilities to work with
Arrowdata and types. - compress
- compute
- Compute kernels on top of Vortex Arrays.
- elementwise
- encoding
- Traits and types to define shared unique encoding identifiers.
- iter
- paste
- github crates-io docs-rs
- stats
- Traits and utilities to compute and access array statistics.
- stream
- validity
- Array validity and nullability behavior, used by arrays and compute functions.
- variants
- This module defines array traits for each Vortex DType.
Macros
- impl_
encoding - Macro to generate all the necessary code for a new type of array encoding. Including:
Structs
- Array
Children Iterator - A depth-first pre-order iterator over a ArrayData.
- Array
Data - Owned
Arraywith serialized metadata, backed by heap-allocated memory. - Array
View - Zero-copy view over flatbuffer-encoded array data, created without eager serialization.
- Context
- A mapping between an encoding’s ID to an
EncodingRef, used to have a shared view of all available encoding schemes. - Typed
Array - Container for an array with all the associated implementation type information (encoding reference and ID, actual array type, metadata type).
Enums
- Array
- A central type for all Vortex arrays, which are known length sequences of typed and possibly compressed data.
- Canonical
- The set of canonical array encodings, also the set of encodings that can be transferred to Arrow with zero-copy.
Traits
- ArrayD
Type - Array
Def - Trait the defines the set of types relating to an array. Because it has associated types it can’t be used as a trait object.
- Array
Len - Array
Metadata - Dynamic trait used to represent opaque owned Array metadata
- Array
Trait - Collects together the behavior of an array.
- GetArray
Metadata - Into
Array - Consume
selfand turn it into anArrayinfallibly. - Into
Array Variant - Trait for types that can be converted from an owned type into an owned array variant.
- Into
Canonical - Support trait for transmuting an array into its vortex_dtype::DType’s canonical encoding.
- ToArray
- ToArray
Data - TryDeserialize
Array Metadata - TrySerialize
Array Metadata