pub trait Display {
// Required method
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}Expand description
Format trait for an empty format, {}.
Implementing this trait for a type will automatically implement the
ToString trait for the type, allowing the usage
of the .to_string() method. Prefer implementing
the Display trait for a type, rather than ToString.
Display is similar to Debug, but Display is for user-facing
output, and so cannot be derived.
For more information on formatters, see the module-level documentation.
Completeness and parseability
Display for a type might not necessarily be a lossless or complete representation of the type.
It may omit internal state, precision, or other information the type does not consider important
for user-facing output, as determined by the type. As such, the output of Display might not be
possible to parse, and even if it is, the result of parsing might not exactly match the original
value.
However, if a type has a lossless Display implementation whose output is meant to be
conveniently machine-parseable and not just meant for human consumption, then the type may wish
to accept the same format in FromStr, and document that usage. Having both Display and
FromStr implementations where the result of Display cannot be parsed with FromStr may
surprise users.
Internationalization
Because a type can only have one Display implementation, it is often preferable
to only implement Display when there is a single most “obvious” way that
values can be formatted as text. This could mean formatting according to the
“invariant” culture and “undefined” locale, or it could mean that the type
display is designed for a specific culture/locale, such as developer logs.
If not all values have a justifiably canonical textual format or if you want
to support alternative formats not covered by the standard set of possible
formatting traits, the most flexible approach is display adapters: methods
like str::escape_default or Path::display which create a wrapper
implementing Display to output the specific display format.
Examples
Implementing Display on a type:
use std::fmt;
struct Point {
x: i32,
y: i32,
}
impl fmt::Display for Point {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "({}, {})", self.x, self.y)
}
}
let origin = Point { x: 0, y: 0 };
assert_eq!(format!("The origin is: {origin}"), "The origin is: (0, 0)");Required Methods
1.0.0 · Sourcefn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Formats the value using the given formatter.
Errors
This function should return Err if, and only if, the provided Formatter returns Err.
String formatting is considered an infallible operation; this function only
returns a Result because writing to the underlying stream might fail and it must
provide a way to propagate the fact that an error has occurred back up the stack.
Examples
use std::fmt;
struct Position {
longitude: f32,
latitude: f32,
}
impl fmt::Display for Position {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "({}, {})", self.longitude, self.latitude)
}
}
assert_eq!(
"(1.987, 2.983)",
format!("{}", Position { longitude: 1.987, latitude: 2.983, }),
);Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl Display for !
impl Display for ALPData
impl Display for ALPRDData
impl Display for Aborted
impl Display for AccessError
impl Display for AcquireError
impl Display for AddrParseError
impl Display for AggregateFnOptions<'_>
impl Display for AggregateFnRef
impl Display for Alignment
impl Display for vortex::array::smallvec::alloc::alloc::AllocError
impl Display for allocator_api2::stable::alloc::AllocError
impl Display for Arguments<'_>
impl Display for Arity
impl Display for ArrayRef
Display the encoding and limited metadata of this array.
Examples
let array = buffer![0_i16, 1, 2, 3, 4].into_array();
assert_eq!(
format!("{}", array),
"vortex.primitive(i16, len=5)",
);impl Display for ArrowError
impl Display for AsciiChar
impl Display for Ast
Print a display representation of this Ast.
This does not preserve any of the original whitespace formatting that may have originally been present in the concrete syntax from which this Ast was generated.
This implementation uses constant stack space and heap space proportional
to the size of the Ast.
impl Display for Attribute
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Attributes
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Authority
impl Display for Backtrace
impl Display for rand::distr::bernoulli::BernoulliError
impl Display for rand::distr::bernoulli::BernoulliError
impl Display for BetweenOptions
impl Display for BigEndian
impl Display for BigInt
impl Display for BigUint
impl Display for BinaryScalar<'_>
impl Display for BitBuffer
impl Display for BitPackedData
impl Display for BoolData
impl Display for BoolScalar<'_>
impl Display for BorrowError
impl Display for BorrowMutError
impl Display for BoundedMaxOptions
impl Display for BoundedMinOptions
impl Display for Braced
impl Display for regex_automata::dfa::onepass::BuildError
impl Display for regex_automata::hybrid::error::BuildError
impl Display for regex_automata::meta::error::BuildError
impl Display for regex_automata::nfa::thompson::error::BuildError
impl Display for aho_corasick::util::error::BuildError
impl Display for ByteBoolData
impl Display for ByteStr
impl Display for ByteString
impl Display for CacheError
impl Display for Canceled
impl Display for CaseFoldError
impl Display for CaseWhenOptions
impl Display for CharTryFromError
impl Display for CheckedCastError
impl Display for ChunkedData
impl Display for ChunkedStore
impl Display for CloseError
impl Display for CollectionAllocErr
impl Display for CompareOperator
impl Display for ConstantData
impl Display for ContentSizeError
impl Display for DDSketchError
impl Display for DType
impl Display for DataError
impl Display for DataErrorKind
impl Display for DataIdentifierBorrowed<'_>
impl Display for DataLocale
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for DataType
impl Display for jiff::civil::date::Date
impl Display for DatePart
impl Display for jiff::civil::datetime::DateTime
Converts a DateTime into an ISO 8601 compliant string.
Formatting options supported
std::fmt::Formatter::precisioncan be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.
Example
This shows the default rendering:
use jiff::civil::date;
// No fractional seconds:
let dt = date(2024, 6, 15).at(7, 0, 0, 0);
assert_eq!(format!("{dt}"), "2024-06-15T07:00:00");
// With fractional seconds:
let dt = date(2024, 6, 15).at(7, 0, 0, 123_000_000);
assert_eq!(format!("{dt}"), "2024-06-15T07:00:00.123");
Example: setting the precision
use jiff::civil::date;
let dt = date(2024, 6, 15).at(7, 0, 0, 123_000_000);
assert_eq!(format!("{dt:.6}"), "2024-06-15T07:00:00.123000");
// Precision values greater than 9 are clamped to 9.
assert_eq!(format!("{dt:.300}"), "2024-06-15T07:00:00.123000000");
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(format!("{dt:.0}"), "2024-06-15T07:00:00");
impl Display for DateTimePartsData
impl Display for DateValue
impl Display for DecimalBytePartsData
impl Display for DecimalDType
impl Display for DecimalData
impl Display for DecimalScalar<'_>
impl Display for DecimalType
impl Display for DecimalValue
impl Display for prost::error::DecodeError
impl Display for base64::decode::DecodeError
impl Display for sketches_ddsketch::encoding::DecodeError
impl Display for DecodeSliceError
impl Display for DecodeUtf16Error
impl Display for DeltaData
impl Display for DeserializeError
impl Display for DictData
impl Display for std::ffi::os_str::Display<'_>
impl Display for std::path::Display<'_>
impl Display for DisplayArrayAs<'_>
impl Display for DisplayLayoutTree
impl Display for DisplayTreeExpr<'_>
impl Display for DuplicateHandling
impl Display for Duration
impl Display for DurationError
impl Display for DynamicComparisonExpr
impl Display for Elapsed
impl Display for rand::distr::slice::Empty
impl Display for rand::distr::slice::Empty
impl Display for EmptyArrayData
impl Display for EmptyMetadata
impl Display for vortex::aggregate_fn::EmptyOptions
impl Display for vortex::scalar_fn::EmptyOptions
impl Display for EncodeError
impl Display for EncodeSliceError
impl Display for EnterError
impl Display for ErrString
impl Display for rustix::backend::io::errno::Errno
impl Display for errno::Errno
impl Display for std::io::error::Error
impl Display for vortex::array::smallvec::alloc::fmt::Error
impl Display for getrandom::error::Error
impl Display for serde_core::de::value::Error
impl Display for serde_json::error::Error
impl Display for object_store::path::Error
impl Display for object_store::Error
impl Display for tokio::time::error::Error
impl Display for icu_collections::codepointtrie::error::Error
impl Display for walkdir::error::Error
impl Display for http::error::Error
impl Display for jiff::error::Error
impl Display for uuid::error::Error
impl Display for getrandom::error::Error
impl Display for lexical_util::error::Error
impl Display for regex::error::Error
impl Display for regex_syntax::ast::Error
impl Display for regex_syntax::error::Error
impl Display for regex_syntax::hir::Error
impl Display for rand::distr::uniform::Error
impl Display for rand::distr::weighted::Error
impl Display for onpair::config::Error
impl Display for rand::distr::uniform::Error
impl Display for rand::distr::weighted::Error
impl Display for rand_core::error::Error
impl Display for core::io::error::ErrorKind
impl Display for regex_syntax::ast::ErrorKind
impl Display for regex_syntax::hir::ErrorKind
impl Display for Errors
impl Display for core::char::EscapeDebug
impl Display for core::ascii::EscapeDefault
impl Display for core::char::EscapeDefault
impl Display for core::char::EscapeUnicode
impl Display for ExecutionCtx
impl Display for ExitStatus
impl Display for ExitStatusError
impl Display for Exponents
impl Display for Expression
The default display implementation for expressions uses the ‘SQL’-style format.
impl Display for ExtDTypeRef
impl Display for ExtScalar<'_>
impl Display for ExtendedTable
impl Display for Extensions
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for FSSTData
impl Display for vortex::dtype::Field
impl Display for arrow_schema::field::Field
impl Display for tracing_core::field::Field
impl Display for FieldName
impl Display for FieldNames
impl Display for FieldPath
impl Display for FieldSelection
impl Display for FieldSet
impl Display for Fields
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for FilterData
impl Display for FixedOffset
impl Display for FixedShapeTensorMetadata
impl Display for FixedSizeListData
impl Display for FoRData
impl Display for ForeignScalarFnOptions
impl Display for FormatVersion
impl Display for FromBytesUntilNulError
impl Display for FromBytesWithNulError
impl Display for FromUtf8Error
impl Display for FromUtf16Error
impl Display for FromVecWithNulError
impl Display for vortex::array::smallvec::alloc::slice::GetDisjointMutError
impl Display for slab::GetDisjointMutError
impl Display for GetRange
impl Display for GetTimezoneError
impl Display for Gid
impl Display for GlobError
impl Display for GroupInfoError
impl Display for HeaderName
impl Display for Hir
Print a display representation of this Hir.
The result of this is a valid regular expression pattern string.
This implementation uses constant stack space and heap space proportional
to the size of the Hir.
impl Display for Hyphenated
impl Display for ISOWeekDate
impl Display for vortex::session::registry::Id
impl Display for tokio::runtime::task::id::Id
impl Display for tokio::runtime::id::Id
impl Display for InMemory
impl Display for Infallible
impl Display for InlinedName
impl Display for IntegerTooSmall
impl Display for IntoStringError
impl Display for InvalidFlatbuffer
impl Display for InvalidHeaderName
impl Display for InvalidHeaderValue
impl Display for InvalidMethod
impl Display for InvalidPart
impl Display for InvalidParts
impl Display for InvalidSetError
impl Display for InvalidStatusCode
impl Display for InvalidStringList
impl Display for InvalidUri
impl Display for InvalidUriParts
impl Display for IpAddr
impl Display for Ipv4Addr
impl Display for Ipv6Addr
Writes an Ipv6Addr, conforming to the canonical style described by RFC 5952.
impl Display for IsSortedOptions
impl Display for JoinError
impl Display for JoinPathsError
impl Display for icu_locale_core::extensions::transform::key::Key
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for icu_locale_core::extensions::unicode::key::Key
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Keywords
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Label
impl Display for Language
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for LanguageIdentifier
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for LassoError
impl Display for LassoErrorKind
impl Display for LayoutError
impl Display for Level
impl Display for LevelFilter
impl Display for LikeOptions
impl Display for ListData
impl Display for ListScalar<'_>
impl Display for ListViewData
impl Display for LittleEndian
impl Display for LocalFileSystem
impl Display for Locale
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for Location<'_>
impl Display for MaskedData
impl Display for regex_automata::util::search::MatchError
impl Display for aho_corasick::util::error::MatchError
impl Display for MaxSizeReached
impl Display for Method
impl Display for NaiveDate
The Display output of the naive date d is the same as
d.format("%Y-%m-%d").
The string printed can be readily parsed via the parse method on str.
Example
use chrono::NaiveDate;
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(2015, 9, 5).unwrap()), "2015-09-05");
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(0, 1, 1).unwrap()), "0000-01-01");
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(9999, 12, 31).unwrap()), "9999-12-31");ISO 8601 requires an explicit sign for years before 1 BCE or after 9999 CE.
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(-1, 1, 1).unwrap()), "-0001-01-01");
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(10000, 12, 31).unwrap()), "+10000-12-31");impl Display for NaiveDateTime
The Display output of the naive date and time dt is the same as
dt.format("%Y-%m-%d %H:%M:%S%.f").
It should be noted that, for leap seconds not on the minute boundary, it may print a representation not distinguishable from non-leap seconds. This doesn’t matter in practice, since such leap seconds never happened. (By the time of the first leap second on 1972-06-30, every time zone offset around the world has standardized to the 5-minute alignment.)
Example
use chrono::NaiveDate;
let dt = NaiveDate::from_ymd_opt(2016, 11, 15).unwrap().and_hms_opt(7, 39, 24).unwrap();
assert_eq!(format!("{}", dt), "2016-11-15 07:39:24");Leap seconds may also be used.
let dt =
NaiveDate::from_ymd_opt(2015, 6, 30).unwrap().and_hms_milli_opt(23, 59, 59, 1_500).unwrap();
assert_eq!(format!("{}", dt), "2015-06-30 23:59:60.500");impl Display for NaiveTime
The Display output of the naive time t is the same as
t.format("%H:%M:%S%.f").
The string printed can be readily parsed via the parse method on str.
It should be noted that, for leap seconds not on the minute boundary, it may print a representation not distinguishable from non-leap seconds. This doesn’t matter in practice, since such leap seconds never happened. (By the time of the first leap second on 1972-06-30, every time zone offset around the world has standardized to the 5-minute alignment.)
Example
use chrono::NaiveTime;
assert_eq!(format!("{}", NaiveTime::from_hms_opt(23, 56, 4).unwrap()), "23:56:04");
assert_eq!(
format!("{}", NaiveTime::from_hms_milli_opt(23, 56, 4, 12).unwrap()),
"23:56:04.012"
);
assert_eq!(
format!("{}", NaiveTime::from_hms_micro_opt(23, 56, 4, 1234).unwrap()),
"23:56:04.001234"
);
assert_eq!(
format!("{}", NaiveTime::from_hms_nano_opt(23, 56, 4, 123456).unwrap()),
"23:56:04.000123456"
);Leap seconds may also be used.
assert_eq!(
format!("{}", NaiveTime::from_hms_milli_opt(6, 59, 59, 1_500).unwrap()),
"06:59:60.500"
);impl Display for NonNilUuid
impl Display for NonSortedIntegers
impl Display for NormalizeError
impl Display for NulError
impl Display for NullPtrError
impl Display for Nullability
impl Display for Number
impl Display for NumericOperator
impl Display for Offset
impl Display for OnPairData
impl Display for Operator
impl Display for OsError
impl Display for Other
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for OutOfRange
impl Display for OutOfRangeError
impl Display for PType
impl Display for PValue
impl Display for PackOptions
impl Display for PanicHookInfo<'_>
impl Display for PanicInfo<'_>
impl Display for PanicMessage<'_>
impl Display for ParseAlphabetError
impl Display for ParseBigIntError
impl Display for ParseBoolError
impl Display for ParseCharError
impl Display for bitflags::parser::ParseError
impl Display for chrono::format::ParseError
impl Display for url::parser::ParseError
impl Display for icu_locale_core::parser::errors::ParseError
impl Display for tinystr::error::ParseError
impl Display for core::num::float_parse::ParseFloatError
impl Display for num_traits::ParseFloatError
impl Display for ParseIntError
impl Display for ParseLevelError
impl Display for ParseLevelFilterError
impl Display for ParseMonthError
impl Display for ParseWeekdayError
impl Display for PatchedData
impl Display for Path
impl Display for PathAndQuery
impl Display for Pattern
Show the original glob pattern.
impl Display for PatternError
impl Display for regex_automata::util::primitives::PatternIDError
impl Display for aho_corasick::util::primitives::PatternIDError
impl Display for PatternSetInsertError
alloc only.impl Display for PcoData
impl Display for PcoError
impl Display for PercentEncode<'_>
impl Display for Pid
impl Display for PodCastError
impl Display for PoolTable
impl Display for PopError
impl Display for PredicateError
impl Display for PreferencesParseError
impl Display for PrimitiveData
impl Display for PrimitiveScalar<'_>
impl Display for Private
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for RLEData
impl Display for RangeError
impl Display for ReceiveError
impl Display for ReceiveErrorTimeout
impl Display for std::sync::mpsc::RecvError
impl Display for futures_channel::mpsc::RecvError
impl Display for tokio::sync::broadcast::error::RecvError
impl Display for tokio::sync::oneshot::error::RecvError
impl Display for tokio::sync::watch::error::RecvError
impl Display for async_channel::RecvError
impl Display for oneshot::errors::RecvError
async or std only.impl Display for crossbeam_channel::err::RecvError
impl Display for std::sync::mpsc::RecvTimeoutError
impl Display for crossbeam_channel::err::RecvTimeoutError
impl Display for regex::regex::bytes::Regex
impl Display for regex::regex::string::Regex
impl Display for Region
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for RoundingError
impl Display for RunEndData
impl Display for Scalar
impl Display for ScalarFnOptions<'_>
impl Display for ScalarFnRef
impl Display for ScalarValue
impl Display for Schema
impl Display for Scheme
impl Display for SchemeId
impl Display for Script
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for SearchResult
impl Display for SearchSortedSide
impl Display for SegmentId
impl Display for SelectTimeoutError
impl Display for futures_channel::mpsc::SendError
impl Display for kanal::error::SendError
impl Display for SendErrorTimeout
impl Display for SequenceData
impl Display for SerializeError
impl Display for SetGlobalDefaultError
impl Display for SignedDuration
impl Display for Simple
impl Display for SliceData
impl Display for SmallIndexError
impl Display for SocketAddr
impl Display for SocketAddrV4
impl Display for SocketAddrV6
impl Display for SorfOptions
impl Display for SortOptions
impl Display for Span
impl Display for SparseData
impl Display for SpawnError
impl Display for StartError
impl Display for Stat
impl Display for StatOptions
impl Display for regex_automata::util::primitives::StateIDError
impl Display for aho_corasick::util::primitives::StateIDError
impl Display for StatusCode
Formats the status code, including the canonical reason.
Example
assert_eq!(format!("{}", StatusCode::OK), "200 OK");impl Display for String
impl Display for StringEscape<'_>
impl Display for StripPrefixError
impl Display for StructFields
impl Display for StructScalar<'_>
impl Display for SubdivisionId
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for SubdivisionSuffix
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for icu_locale_core::extensions::private::other::Subtag
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for icu_locale_core::subtags::Subtag
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for SyntaxViolation
impl Display for SystemTimeError
impl Display for Table
impl Display for TemporalJiff
impl Display for Time
Converts a Time into an ISO 8601 compliant string.
Formatting options supported
std::fmt::Formatter::precisioncan be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.
Example
use jiff::civil::time;
// No fractional seconds:
let t = time(7, 0, 0, 0);
assert_eq!(format!("{t}"), "07:00:00");
// With fractional seconds:
let t = time(7, 0, 0, 123_000_000);
assert_eq!(format!("{t}"), "07:00:00.123");
Example: setting the precision
use jiff::civil::time;
let t = time(7, 0, 0, 123_000_000);
assert_eq!(format!("{t:.6}"), "07:00:00.123000");
// Precision values greater than 9 are clamped to 9.
assert_eq!(format!("{t:.300}"), "07:00:00.123000000");
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(format!("{t:.0}"), "07:00:00");
impl Display for TimeDelta
impl Display for vortex::extension::datetime::TimeUnit
impl Display for arrow_schema::datatype::TimeUnit
impl Display for TimeValue
impl Display for jiff::timestamp::Timestamp
Converts a Timestamp datetime into a RFC 3339 compliant string.
Since a Timestamp never has an offset associated with it and is always
in UTC, the string emitted by this trait implementation uses Z for “Zulu”
time. The significance of Zulu time is prescribed by RFC 9557 and means
that “the time in UTC is known, but the offset to local time is unknown.”
If you need to emit an RFC 3339 compliant string with a specific offset,
then use Timestamp::display_with_offset.
Formatting options supported
std::fmt::Formatter::precisioncan be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.
Example
This shows the default rendering:
use jiff::Timestamp;
// No fractional seconds.
let ts = Timestamp::from_second(1_123_456_789)?;
assert_eq!(format!("{ts}"), "2005-08-07T23:19:49Z");
// With fractional seconds.
let ts = Timestamp::new(1_123_456_789, 123_000_000)?;
assert_eq!(format!("{ts}"), "2005-08-07T23:19:49.123Z");
Example: setting the precision
use jiff::Timestamp;
let ts = Timestamp::new(1_123_456_789, 123_000_000)?;
assert_eq!(
format!("{ts:.6}"),
"2005-08-07T23:19:49.123000Z",
);
// Precision values greater than 9 are clamped to 9.
assert_eq!(
format!("{ts:.300}"),
"2005-08-07T23:19:49.123000000Z",
);
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(
format!("{ts:.0}"),
"2005-08-07T23:19:49Z",
);
impl Display for prost_types::protobuf::Timestamp
impl Display for TimestampDisplayWithOffset
impl Display for TimestampError
impl Display for TimestampOptions
impl Display for TimestampValue<'_>
impl Display for ToLowercase
impl Display for ToStrError
impl Display for ToTitlecase
impl Display for ToUppercase
impl Display for Transform
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for TreeDisplay
impl Display for TryAcquireError
impl Display for TryCurrentError
impl Display for TryFromCharError
impl Display for TryFromFloatSecsError
impl Display for TryFromIntError
impl Display for TryFromSliceError
impl Display for TryGetError
impl Display for std::fs::TryLockError
impl Display for tokio::sync::mutex::TryLockError
impl Display for std::sync::mpsc::TryRecvError
impl Display for futures_channel::mpsc::TryRecvError
impl Display for tokio::sync::broadcast::error::TryRecvError
impl Display for tokio::sync::mpsc::error::TryRecvError
impl Display for tokio::sync::oneshot::error::TryRecvError
impl Display for async_channel::TryRecvError
impl Display for oneshot::errors::TryRecvError
impl Display for crossbeam_channel::err::TryRecvError
impl Display for vortex::array::smallvec::alloc::collections::TryReserveError
impl Display for allocator_api2::stable::raw_vec::TryReserveError
impl Display for hashbrown::TryReserveError
impl Display for TrySelectError
impl Display for TzOffset
impl Display for Uid
impl Display for UleError
impl Display for Unicode
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for UnicodeWordBoundaryError
impl Display for UnicodeWordError
impl Display for UnknownEnumValue
impl Display for UnorderedKeyError
impl Display for Uri
impl Display for Url
Display the serialization of this URL.
impl Display for Urn
impl Display for Utc
impl Display for Utf8CharsError
impl Display for vortex::array::smallvec::alloc::str::Utf8Error
impl Display for simdutf8::basic::Utf8Error
impl Display for simdutf8::compat::Utf8Error
impl Display for Utf8Scalar<'_>
impl Display for Uuid
impl Display for UuidMetadata
impl Display for serde_json::value::Value
impl Display for icu_locale_core::extensions::transform::value::Value
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for icu_locale_core::extensions::unicode::value::Value
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for ValueFormatter<'_>
impl Display for ValueSet<'_>
impl Display for VarBinData
impl Display for VarBinViewData
impl Display for VarError
impl Display for icu_locale_core::subtags::variant::Variant
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for uuid::Variant
impl Display for VariantGetOptions
impl Display for VariantPath
impl Display for VariantScalar<'_>
impl Display for Variants
This trait is implemented for compatibility with fmt!.
To create a string, [Writeable::write_to_string] is usually more efficient.
impl Display for VortexError
impl Display for Weekday
impl Display for WeekdaySet
Print the collection as a slice-like list of weekdays.
Example
use chrono::Weekday::*;
assert_eq!("[]", WeekdaySet::EMPTY.to_string());
assert_eq!("[Mon]", WeekdaySet::single(Mon).to_string());
assert_eq!("[Mon, Fri, Sun]", WeekdaySet::from_array([Mon, Fri, Sun]).to_string());impl Display for WouldBlock
impl Display for WriterPanicked
impl Display for ZeroTrieBuildError
impl Display for ZigZagData
impl Display for Zoned
Converts a Zoned datetime into a RFC 9557 compliant string.
Formatting options supported
std::fmt::Formatter::precisioncan be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.
Example
This shows the default rendering:
use jiff::civil::date;
// No fractional seconds:
let zdt = date(2024, 6, 15).at(7, 0, 0, 0).in_tz("US/Eastern")?;
assert_eq!(format!("{zdt}"), "2024-06-15T07:00:00-04:00[US/Eastern]");
// With fractional seconds:
let zdt = date(2024, 6, 15).at(7, 0, 0, 123_000_000).in_tz("US/Eastern")?;
assert_eq!(format!("{zdt}"), "2024-06-15T07:00:00.123-04:00[US/Eastern]");
Example: setting the precision
use jiff::civil::date;
let zdt = date(2024, 6, 15).at(7, 0, 0, 123_000_000).in_tz("US/Eastern")?;
assert_eq!(
format!("{zdt:.6}"),
"2024-06-15T07:00:00.123000-04:00[US/Eastern]",
);
// Precision values greater than 9 are clamped to 9.
assert_eq!(
format!("{zdt:.300}"),
"2024-06-15T07:00:00.123000000-04:00[US/Eastern]",
);
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(
format!("{zdt:.0}"),
"2024-06-15T07:00:00-04:00[US/Eastern]",
);
impl Display for ZstdBuffersData
impl Display for ZstdData
impl Display for bf16
impl Display for bool
impl Display for char
impl Display for dyn Expected + '_
impl Display for dyn Layout + '_
Display the encoding, dtype, row count, and segment IDs of this layout.
impl Display for dyn LayoutEncoding + '_
impl Display for dyn Value
impl Display for f16
impl Display for f16
impl Display for f32
impl Display for f64
impl Display for i8
impl Display for i16
impl Display for i32
impl Display for i64
impl Display for i128
impl Display for vortex::dtype::i256
impl Display for arrow_buffer::bigint::i256
impl Display for isize
impl Display for str
impl Display for u8
impl Display for u16
impl Display for u32
impl Display for u64
impl Display for u128
impl Display for usize
impl<'a, 'e, E> Display for Base64Display<'a, 'e, E>where
E: Engine,
impl<'a, I, B> Display for DelayedFormat<I>
alloc only.impl<'a, I> Display for Format<'a, I>
impl<'a, K, V, S, A> Display for hashbrown::map::OccupiedError<'a, K, V, S, A>
impl<'a, R, G, T> Display for MappedReentrantMutexGuard<'a, R, G, T>
impl<'a, R, G, T> Display for ReentrantMutexGuard<'a, R, G, T>
impl<'a, R, T> Display for lock_api::mutex::MappedMutexGuard<'a, R, T>
impl<'a, R, T> Display for lock_api::rwlock::MappedRwLockReadGuard<'a, R, T>
impl<'a, R, T> Display for lock_api::rwlock::MappedRwLockWriteGuard<'a, R, T>
impl<'a, R, T> Display for lock_api::mutex::MutexGuard<'a, R, T>
impl<'a, R, T> Display for lock_api::rwlock::RwLockReadGuard<'a, R, T>
impl<'a, R, T> Display for lock_api::rwlock::RwLockUpgradableReadGuard<'a, R, T>
impl<'a, R, T> Display for lock_api::rwlock::RwLockWriteGuard<'a, R, T>
impl<'a, T, O> Display for Domain<'a, Const, T, O>
impl<'a, T> Display for tokio::sync::mutex::MappedMutexGuard<'a, T>
impl<'a, T> Display for RwLockMappedWriteGuard<'a, T>
impl<'a, T> Display for tokio::sync::rwlock::read_guard::RwLockReadGuard<'a, T>
impl<'a, T> Display for tokio::sync::rwlock::write_guard::RwLockWriteGuard<'a, T>
impl<'a> Display for EscapeAscii<'a>
impl<'a> Display for vortex::array::smallvec::alloc::str::EscapeDebug<'a>
impl<'a> Display for vortex::array::smallvec::alloc::str::EscapeDefault<'a>
impl<'a> Display for vortex::array::smallvec::alloc::str::EscapeUnicode<'a>
impl<'a> Display for Unexpected<'a>
impl<'d> Display for TimeZoneName<'d>
impl<'f> Display for jiff::fmt::strtime::Display<'f>
impl<'n> Display for Pieces<'n>
impl<A, B> Display for Concat<A, B>
impl<A, O> Display for BitArray<A, O>where
O: BitOrder,
A: BitViewSized,
impl<A, S, V> Display for ConvertError<A, S, V>
Produces a human-readable error message.
The message differs between debug and release builds. When
debug_assertions are enabled, this message is verbose and includes
potentially sensitive information.
impl<A> Display for PartitionedExpr<A>where
A: Display,
impl<B> Display for bit_vec::BitVec<B>where
B: BitBlock,
impl<B> Display for Cow<'_, B>
impl<D> Display for PrecisionScale<D>where
D: NativeDecimalType,
impl<D> Display for Tree<D>where
D: Display,
impl<E> Display for ParseComplexError<E>where
E: Display,
impl<E> Display for Report<E>where
E: Error,
impl<Enum> Display for TryFromPrimitiveError<Enum>where
Enum: TryFromPrimitive,
impl<F> Display for FromFn<F>
impl<I, F> Display for FormatWith<'_, I, F>
impl<I> Display for ExactlyOneError<I>where
I: Iterator,
impl<K, V, S, A> Display for hashbrown::map::OccupiedError<'_, K, V, S, A>
impl<K, V, S, A> Display for hashbrown::map::OccupiedError<'_, K, V, S, A>
impl<K, V, T> Display for MappedRef<'_, K, V, T>
impl<L, R> Display for Either<L, R>
impl<L, R> Display for PairOptions<L, R>
impl<M, T, O> Display for BitRef<'_, M, T, O>
tarpaulin_include only.impl<O> Display for F32<O>where
O: ByteOrder,
impl<O> Display for F64<O>where
O: ByteOrder,
impl<O> Display for I16<O>where
O: ByteOrder,
impl<O> Display for I32<O>where
O: ByteOrder,
impl<O> Display for I64<O>where
O: ByteOrder,
impl<O> Display for I128<O>where
O: ByteOrder,
impl<O> Display for Isize<O>where
O: ByteOrder,
impl<O> Display for U16<O>where
O: ByteOrder,
impl<O> Display for U32<O>where
O: ByteOrder,
impl<O> Display for U64<O>where
O: ByteOrder,
impl<O> Display for U128<O>where
O: ByteOrder,
impl<O> Display for Usize<O>where
O: ByteOrder,
impl<Ptr> Display for Pin<Ptr>where
Ptr: Display,
impl<R, D, G, C> Display for CompactGrid<R, D, G, C>
impl<R, G, D, C> Display for PeekableGrid<R, G, D, C>where
R: Records + PeekableRecords + ExactRecords,
D: Dimension,
C: Colors,
G: Borrow<SpannedConfig>,
impl<R> Display for BitEnd<R>where
R: BitRegister,
impl<R> Display for BitIdx<R>where
R: BitRegister,
impl<R> Display for BitIdxError<R>where
R: BitRegister,
tarpaulin_include only.impl<R> Display for BitMask<R>where
R: BitRegister,
impl<R> Display for BitPos<R>where
R: BitRegister,
impl<R> Display for BitSel<R>where
R: BitRegister,
impl<S> Display for Host<S>
impl<S> Display for Text<S>where
S: Display,
impl<Src, Dst> Display for AlignmentError<Src, Dst>
Produces a human-readable error message.
The message differs between debug and release builds. When
debug_assertions are enabled, this message is verbose and includes
potentially sensitive information.
impl<Src, Dst> Display for SizeError<Src, Dst>
Produces a human-readable error message.
The message differs between debug and release builds. When
debug_assertions are enabled, this message is verbose and includes
potentially sensitive information.
impl<Src, Dst> Display for ValidityError<Src, Dst>
Produces a human-readable error message.
The message differs between debug and release builds. When
debug_assertions are enabled, this message is verbose and includes
potentially sensitive information.
impl<T, A> Display for Arc<T, A>
impl<T, A> Display for vortex::array::smallvec::alloc::boxed::Box<T, A>
impl<T, A> Display for allocator_api2::stable::boxed::Box<T, A>
impl<T, A> Display for Rc<T, A>
impl<T, A> Display for UniqueArc<T, A>
impl<T, A> Display for UniqueRc<T, A>
impl<T, B> Display for zerocopy::ref::def::Ref<B, T>
impl<T, E> Display for TryChunksError<T, E>where
E: Display,
impl<T, E> Display for TryReadyChunksError<T, E>where
E: Display,
impl<T, Item> Display for futures_util::stream::stream::split::ReuniteError<T, Item>
impl<T, O> Display for BitBox<T, O>
impl<T, O> Display for BitSlice<T, O>
impl<T, O> Display for bitvec::vec::BitVec<T, O>
impl<T, O> Display for ISizeFormatter<T, O>
impl<T, O> Display for SizeFormatter<T, O>
impl<T, S> Display for ArcSwapAny<T, S>
impl<T, S> Display for Guard<T, S>
impl<T, U> Display for OwnedMappedMutexGuard<T, U>
impl<T, U> Display for OwnedRwLockMappedWriteGuard<T, U>
impl<T, U> Display for OwnedRwLockReadGuard<T, U>
impl<T> Display for &T
impl<T> Display for &mut T
impl<T> Display for ArcRef<T>
impl<T> Display for BitPtrError<T>where
T: BitStore,
tarpaulin_include only.impl<T> Display for BitSpanError<T>where
T: BitStore,
tarpaulin_include only.impl<T> Display for CachePadded<T>where
T: Display,
impl<T> Display for Compat<T>where
T: ObjectStore,
impl<T> Display for Complex<T>
impl<T> Display for DisplayValue<T>where
T: Display,
impl<T> Display for FmtBinary<T>
tarpaulin_include only.impl<T> Display for FmtDisplay<T>where
T: Display,
tarpaulin_include only.impl<T> Display for FmtList<T>
impl<T> Display for FmtLowerExp<T>
tarpaulin_include only.impl<T> Display for FmtLowerHex<T>
tarpaulin_include only.impl<T> Display for FmtOctal<T>
tarpaulin_include only.impl<T> Display for FmtPointer<T>
tarpaulin_include only.impl<T> Display for FmtUpperExp<T>
tarpaulin_include only.impl<T> Display for FmtUpperHex<T>
tarpaulin_include only.impl<T> Display for ForcePushError<T>
impl<T> Display for LimitStore<T>where
T: ObjectStore,
impl<T> Display for LossyWrap<T>where
T: TryWriteable,
impl<T> Display for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
impl<T> Display for std::sync::poison::mutex::MappedMutexGuard<'_, T>
impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
impl<T> Display for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
impl<T> Display for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
impl<T> Display for MisalignError<T>
tarpaulin_include only.impl<T> Display for std::sync::nonpoison::mutex::MutexGuard<'_, T>
impl<T> Display for std::sync::poison::mutex::MutexGuard<'_, T>
impl<T> Display for tokio::sync::mutex::MutexGuard<'_, T>
impl<T> Display for async_lock::mutex::MutexGuard<'_, T>
impl<T> Display for MutexGuardArc<T>
impl<T> Display for NonZero<T>where
T: ZeroablePrimitive + Display,
impl<T> Display for OwnedMutexGuard<T>
impl<T> Display for OwnedRwLockWriteGuard<T>
impl<T> Display for PoisonError<T>
impl<T> Display for Port<T>
impl<T> Display for Precision<T>where
T: Display,
impl<T> Display for PrefixStore<T>
impl<T> Display for PushError<T>
impl<T> Display for std::sync::oneshot::RecvTimeoutError<T>
impl<T> Display for ReentrantLockGuard<'_, T>
impl<T> Display for core::cell::Ref<'_, T>
impl<T> Display for RefMut<'_, T>
impl<T> Display for futures_util::io::split::ReuniteError<T>
impl<T> Display for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
impl<T> Display for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
impl<T> Display for async_lock::rwlock::RwLockReadGuard<'_, T>
impl<T> Display for RwLockReadGuardArc<T>where
T: Display,
impl<T> Display for async_lock::rwlock::RwLockUpgradableReadGuard<'_, T>
impl<T> Display for RwLockUpgradableReadGuardArc<T>
impl<T> Display for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
impl<T> Display for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
impl<T> Display for async_lock::rwlock::RwLockWriteGuard<'_, T>
impl<T> Display for RwLockWriteGuardArc<T>
impl<T> Display for Saturating<T>where
T: Display,
impl<T> Display for std::sync::mpsc::SendError<T>
impl<T> Display for tokio::sync::broadcast::error::SendError<T>
impl<T> Display for tokio::sync::mpsc::error::SendError<T>
impl<T> Display for tokio::sync::watch::error::SendError<T>
impl<T> Display for async_channel::SendError<T>
impl<T> Display for oneshot::errors::SendError<T>
impl<T> Display for crossbeam_channel::err::SendError<T>
impl<T> Display for std::sync::mpmc::error::SendTimeoutError<T>
impl<T> Display for tokio::sync::mpsc::error::SendTimeoutError<T>
time only.