Compute kernels on top of Vortex Arrays.
We aim to provide a basic set of compute kernels that can be used to efficiently index, slice, and filter Vortex Arrays in their encoded forms.
Every array variant has the ability to implement their own efficient implementations of these operators, else we will decode, and perform the equivalent operator from Arrow.
Modules
Enums
- Operator
- Search
Result - Result of performing search_sorted on an Array
- Search
Sorted Side
Traits
- AndFn
- Array
Compute - Trait providing compute functions on top of Vortex arrays.
- Compare
Fn - Filter
Fn - Index
Ord - Len
- Maybe
Compare Fn - OrFn
- Search
Sorted - Search
Sorted Fn - Searches for value assuming the array is sorted.
- SliceFn
- Limit array to start…stop range
- TakeFn
Functions
- and
- compare
- filter
- Return a new array by applying a boolean predicate to select items from a base Array.
- or
- scalar_
cmp - search_
sorted - search_
sorted_ many - Search for many elements in the array.
- search_
sorted_ u64 - search_
sorted_ u64_ many - slice
- Return a zero-copy slice of an array, between
start(inclusive) andend(exclusive). - take