pub trait TakeFn {
// Required method
fn take(&self, indices: &Array) -> Result<Array, VortexError>;
}Required Methods
Implementations on Foreign Types
Sourceimpl TakeFn for ALPRDArray
impl TakeFn for ALPRDArray
Sourceimpl TakeFn for ByteBoolArray
impl TakeFn for ByteBoolArray
Sourceimpl TakeFn for DateTimePartsArray
impl TakeFn for DateTimePartsArray
Sourceimpl TakeFn for BitPackedArray
impl TakeFn for BitPackedArray
Sourceimpl TakeFn for RunEndBoolArray
impl TakeFn for RunEndBoolArray
Sourceimpl TakeFn for RunEndArray
impl TakeFn for RunEndArray
Implementors
impl TakeFn for BoolArray
impl TakeFn for ChunkedArray
impl TakeFn for ConstantArray
impl TakeFn for ExtensionArray
impl TakeFn for NullArray
impl TakeFn for PrimitiveArray
impl TakeFn for SparseArray
impl TakeFn for StructArray
impl TakeFn for VarBinArray
impl TakeFn for VarBinViewArray
Take involves creating a new array that references the old array, just with the given set of views.